#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os


class CommonConstant:
    # 默认语言
    DEFAULT_LANGUAGE = 'zh-CN'
    """
     媒体文件类型
     * 1-课程介绍视频
     * 2-课程视频文件
     * 3-课程音频文件
     * 4-章节视频文件
     * 5-章节音频文件
    """
    MEDIA_TYPE = {
        'COURSE_INTRODUCTION_VIDEO': 1,
        'COURSE_VIDEO_FILE': 2,
        'COURSE_AUDIO_FILE': 3,
        'LESSON_VIDEO_FILE': 4,
        'LESSON_AUDIO_FILE': 5
    }
    """
     课程、章节学习状态
     * 1-学习中
     * 2-已学完
    """
    LEARNING_STATUS = {
        'LEARNING': 1,
        'FINISHED': 2,
    }
    """
     课程提交动作
     * 0-提交审核
     * 1-提交测试
     * 2-撤销审核
    """
    COURSE_COMMIT_ACTION = {
        'COMMIT_REVIEW': 0,
        'COMMIT_TEST': 1,
        'CANCEL_COMMIT': 2
    }
    """
     期望变更到的状态值
     * 1-课程下架，课程不可推荐、搜索和售卖，但已购用户可以使用。
     * 2-课程上架，课程可推荐、搜索、售卖和使用。
     * 3-课程下架，课程不可推荐、搜索和售卖，已购用户也不可使用。
    """
    COURSE_STATUS_CHANGE = {
        'COURSE_OFFSHELF_AND_PURCHASED_USER_AVAILABLE': 1,
        'COURSE_ONSHELF': 2,
        'COURSE_OFFSHELF_AND_PURCHASED_USER_UNAVAILABLE': 3
    }
    """
     课程售卖模式
     * 0-仅支持课程售卖
     * 1-免费
     * 2-仅支持会员包售卖
     * 3-同时支持单课程售卖和会员包售卖
     * 4-只支持教育中心会员售卖
     * 5-同时支持教育中心会员售卖和单卖
     * 6-同时支持教育中心会员售卖和CP会员售卖
     * 7-同时支持教育中心会员售卖和CP会员售卖和单卖   
    """
    COURSE_SELLING_MODE = {
        'SEPARATELY': 0,
        'FREE': 1,
        'SOLD_BY_PACKAGE_ONLY': 2,
        'SOLD_SEPARATELY_AND_BY_PACKAGE': 3,
        'SOLD_BY_EDUCATION_ONLY': 4,
        'SOLD_SEPARATELY_AND_BY_EDUCATION': 5,
        'SOLD_EDUCATION_AND_BY_CP': 6,
        'SOLD_SEPARATELY_AND_BY_CP_AND_BY_EDUCATION': 7
    }
    """
     有效期单位
     * 1-无限制：此时忽略validityNum的值，课程购买后永久有效
     * 2-天
     * 3-周
     * 4-月
     * 5-年
    """
    VALIDITY_UNIT = {
        'PERMANENT': 1,
        'DAY': 2,
        'WEEK': 3,
        'MONTH': 4,
        'YEAR': 5
    }
    """
     课程类型
     * 1000-其它类型
     * 1001-直播课
     * 1002-录播课
     * 1003-教辅教材
     * 1004-绘本
    """
    COURSE_TYPE = {
        'OTHERS': 1000,
        'LIVE': 1001,
        'RECORDED': 1002,
        'TEACHING_MATERIALS': 1003,
        'DRAWING_BOOK': 1004,
    }
    """
     订购状态
     * 2-已订购
     * 4-已退订
    """
    SUBSCRIPTION_STATUS = {'SUBSCRIBED': 2, 'UNSUBSCRIBED': 4}
    """
     价格类型
     * 1-原始价格。可用在降价促销等场景展示商品原始价格；教育中心App显示原价时，将使用删除线进行标识
     * 2-售卖价格。用户购买商品时实际需要支付的价格
    """
    PRICE_TYPE = {'ORIGINAL': 1, 'CURRENT': 2}
    """
     课程或章节的媒体类型
     * 1-音频
     * 2-视频
     * 3-绘本
    """
    COURSE_LESSON_MEDIA_TYPE = {'AUDIO': 1, 'VIDEO': 2, 'DRAWING_BOOK': 3}

    CREDENTIAL_LIST = {
        'client_id': '235889897037149184',
        'client_secret': '55A5C9CA1E983328DA7E020B'
        '1A1CC4B02AEB80BFF60F648F74997670D45C7EFF',
        'grant_type': 'client_credentials'
    }

    CONFIG_DIR = 'config'
    AUTH_DIR = 'ssl'
    LOG_DIR = os.path.join('storage', 'log')

    # 文件访问类型
    FILE_MODE_READ = 'rb'
    FILE_MODE_CREATE_WRITE = 'wb+'
    FILE_MODE_CREDENTIAL_WRITE = 'w'

    # 内存访问类型
    SHMOP_MODE_CREATE = 'c'

    # 文件访问权限
    FILE_DEFAULT_MOD = 0o640

    # 目录访问权限
    DIR_DEFAULT_MOD = 0o740

    # 证书
    CERT = 'cacert.pem'
    REFRESH_TIME_BEFORE_EXPIRE = 3600

    # 返回状态
    RESULT_SUCCESS = 0

    # 获取默认证书文件
    DEFAULT_CERT_URL = 'http://curl.haxx.se/ca/cacert.pem'

    # 项目名
    PROJECT_NAME = 'edukit_sdk'

    # 根目录
    cur_path = os.path.abspath(os.path.dirname(__file__))
    ROOT_PATH = os.path.abspath(
        os.path.dirname(__file__))[:cur_path.find(PROJECT_NAME) +
                                   len(PROJECT_NAME)]



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.catalogue.impl.catalogue_handler import CatalogueHandler
from edukit_sdk.edukit.catalogue.model.catalogue import Catalogue
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class CatalogueUpdateRequest:
    def __init__(self, catalogue: Catalogue, course_id, course_edit_id,
                 credential_list):
        self._catalogue = catalogue
        self._course_id = course_id
        self._course_edit_id = course_edit_id
        self._catalogue_handler = CatalogueHandler(
            EduKitRequestSender(credential_list))

    def update(self):
        return self._catalogue_handler.update_catalogue(
            self._catalogue, self._course_id, self._course_edit_id)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ErrorConstant:
    # 文件相关
    FILE_UPLOAD_ERROR = 'The file upload failed!'
    FILE_NOT_EXISTS = 'File or directory {} does not exists!'
    PATH_NOT_NULL = 'The file path can not be null!'
    PATH_NOT_ABSOLUTE = 'The file path is not absolute!'
    PATH_IS_DIRECTORY = '{} is a directory!'
    FILE_TYPE_OR_PUBLIC_FILE_NOT_NULL = \
        'The element fileType and publicFile should be null ' \
        'when resourceType has value!'
    RESOURCE_TYPE_IS_INVALID = 'The resourceType is invalid'
    FILE_TYPE_NO_VALUE = 'The element fileType should have value ' \
                         'when resourceType is null!'
    FILE_TYPE_ERROR = "The file type to be uploaded is not supported."
    PICTURE_FILE_TYPE_ERROR = "The file type to be uploaded is not" \
                              " supported, that must be one of .png, .jpg."
    MEDIA_FILE_TYPE_ERROR = "The file type to be uploaded is not supported," \
                            " that must be one of .mp3, .mp4, .wav, .mov."

    # 文件
    CREDENTIAL_IS_EMPTY = 'The credential can not be empty!'
    PARAM_CANNOT_BE_EMPTY = 'The input parameters can not be empty!'



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class ChangeCourseStatusData:
    def __init__(self):
        self._remarks = None
        self._removal_reason = None

    @property
    def remarks(self):
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        self._remarks = remarks

    @property
    def removal_reason(self):
        return self._removal_reason

    @removal_reason.setter
    def removal_reason(self, removal_reason):
        self._removal_reason = removal_reason

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class TeacherBasicInfo:
    def __init__(self):
        self._dev_teacher_id = None

    @property
    def dev_teacher_id(self):
        """
        :return: mixed
        """
        return self._dev_teacher_id

    @dev_teacher_id.setter
    def dev_teacher_id(self, dev_teacher_id):
        """
        由您指定的教师编号
        :param dev_teacher_id:
        :return:
        """
        self._dev_teacher_id = dev_teacher_id

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class CreateLessonRequest:
    def __init__(self):
        self._display_order = None
        self._catalogue_id = None

    @property
    def display_order(self):
        """
        :return:mixed
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """
        :param display_order:
        """
        self._display_order = display_order

    @property
    def catalogue_id(self):
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        self._catalogue_id = catalogue_id

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class AlbumEdit:
    def __init__(self):
        self._meta_data = None
        self._localized_data = None
        self._course_list = None
        self._sub_album_list = None

    @property
    def localized_data(self):
        """
        :return:mixed
        """
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data):
        """
        本地化多语言数据
        :param localized_data:
        :return:
        """
        self._localized_data = localized_data

    @property
    def meta_data(self):
        """
        :return:mixed
        """
        return self._meta_data

    @meta_data.setter
    def meta_data(self, meta_data):
        """
        版本元数据
        :param mete_data:
        :return:
        """
        self._meta_data = meta_data

    @property
    def course_list(self):
        """
        :return:mixed
        """
        return self._course_list

    @course_list.setter
    def course_list(self, course_list):
        """
        课程ID列表信息，最大2000个
        :param course_list:
        :return:
        """
        self._course_list = course_list

    @property
    def sub_album_list(self):
        """
        :return:mixed
        """
        return self._sub_album_list

    @sub_album_list.setter
    def sub_album_list(self, sub_album_list):
        """
        专辑ID列表信息，最大20个
        :param sub_album_list:
        :return:
        """
        self._sub_album_list = sub_album_list

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class CourseSignupWithMultipleOrder:
    def __init__(self):
        self._course_id = None
        self._expire = None
        self._orders = None

    @property
    def course_id(self):
        """
        :return:
        """
        return self._course_id

    @course_id.setter
    def course_id(self, course_id):
        """
        设置用户订购/退订的课程ID。
        :param course_id:
        :return:
        """
        self._course_id = course_id

    @property
    def expire(self):
        """
        :return:
        """
        return self._expire

    @expire.setter
    def expire(self, expire):
        """
        设置订购关系的失效时间。
        订购状态为“2：已订购”时，您可以通过此字段显式指定订购关系的失效时间。
        超过此时间的后用户不可再使用此课程/会员包。
        该字段可选。如果您不指定此字段，将根据订购时间以及您创建课程时设置的订购关系有效期(validityNum)自动计算失效时间。
        :param expire:
        :return:
        """
        self._expire = expire

    @property
    def orders(self):
        """
        :return:
        """
        return self._orders

    @orders.setter
    def orders(self, orders):
        """
        设置该订购记录对应的订单列表。
        如果一次课程购买对应了多笔支付订单（如定金+尾款场景），可一次性传递所有订单。
        :param orders:
        :return:
        """
        self._orders = orders

    def to_json_string(self):
        """
        to_string
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.course.impl.update_edit_localized_data import \
    UpdateEditLocalizedData


class UpdateLocalizedDataRequest:
    def __init__(self):
        self._localized_data = None
        self._localized_media = None

    @property
    def localized_data(self):
        return self._localized_data

    @localized_data.setter
    def localized_data(self, localized_data: UpdateEditLocalizedData):
        self._localized_data = localized_data

    @property
    def localized_media(self):
        return self._localized_media

    @localized_media.setter
    def localized_media(self, localized_media):
        self._localized_media = localized_media

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class PackageSignupInfo:
    def __init__(self):
        self._package_id = None
        self._product_no = None
        self._signup_info = None

    @property
    def package_id(self):
        """
        :return:
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """
        设置会员包ID。
        教育中心分配的会员包ID，通过getPkgId()接口获取。
        :param package_id:
        :return:
        """
        self._package_id = package_id

    @property
    def product_no(self):
        """
        :return:
        """
        return self._product_no

    @product_no.setter
    def product_no(self, product_no):
        """
        由您分配的商品ID，需要与创建会员包商品时指定的devProductId相同。
        :param product_no:
        :return:
        """
        self._product_no = product_no

    @property
    def signup_info(self):
        """
        mixed
        :return:
        """
        return self._signup_info

    @signup_info.setter
    def signup_info(self, signup_info):
        """
        设置订购关系信息
        :param signup_info:
        :return:
        """
        self._signup_info = signup_info

    def to_json_string(self):
        """
        to_string
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.catalogue.impl.catalogue_handler import CatalogueHandler
from edukit_sdk.edukit.catalogue.model.catalogue_edit_data import \
    CatalogueEditData
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class CatalogueCreateRequest:
    def __init__(self, catalogue_edit_data: CatalogueEditData, course_id,
                 course_edit_id, credential_list):
        self._catalogue_edit_data = catalogue_edit_data
        self._course_id = course_id
        self._course_edit_id = course_edit_id
        self._catalogue_handler = CatalogueHandler(
            EduKitRequestSender(credential_list))

    def create(self):
        return self._catalogue_handler.create_catalogue(
            self._catalogue_edit_data, self._course_id, self._course_edit_id)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class MediaFileInfo:
    def __init__(self):
        self._path = None
        self._file_type = None

    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, path):
        self._path = path

    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        self._file_type = file_type



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.model.response import Response
from edukit_sdk.edukit.signup.impl.signup_handler import SignupHandler


class SignupRequest:
    @staticmethod
    def report_signup(user_id, course_id, user_id_type, signup_info,
                      credential_list):
        """
        :param user_id:用户ID
        :param course_id:课程ID
        :param user_id_type:user_id字段对应的帐号类型
        :param signup_info:相关类
        :param credential_list:用户凭据
        :return:
        """
        response = Response()

        if Helpers.has_empty_param(
            [
                user_id,
                course_id,
                user_id_type,
                signup_info,
                credential_list]):
            response.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return response
        signup_handler = SignupHandler(EduKitRequestSender(credential_list))
        return signup_handler.report_signup(user_id, course_id, user_id_type,
                                            signup_info)

    @staticmethod
    def report_signup_package(user_id, user_id_type, package_signup_info,
                              credential_list):
        """
        :param user_id:用户ID
        :param user_id_type:user_id字段对应的帐号类型
        :param package_signup_info:相关类
        :param credential_list:用户凭据
        :return:
        """
        response = Response()
        if Helpers.has_empty_param(
            [
                user_id,
                user_id_type,
                package_signup_info
            ]
        ):
            response.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return response
        signup_handler = SignupHandler(EduKitRequestSender(credential_list))
        return signup_handler.report_signup_package(
            user_id,
            user_id_type,
            package_signup_info
        )

    @staticmethod
    def batch_report_signup_course(
            user_id,
            user_id_type,
            batch_report_signup_course_request,
            credential_list
    ):
        """
        :param user_id:用户ID
        :param user_id_type:user_id字段对应的帐号类型
        :param batch_report_signup_course_request:相关类
        :param credential_list:用户凭据
        :return:
        """
        response = Response()
        if Helpers.has_empty_param(
            [
                user_id,
                user_id_type,
                batch_report_signup_course_request
            ]
        ):
            response.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return response
        signup_handler = SignupHandler(EduKitRequestSender(credential_list))
        return signup_handler.batch_report_signup_course(
            user_id,
            user_id_type,
            batch_report_signup_course_request
        )



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.model.media_localized_data import \
    MediaLocalizedData
from edukit_sdk.edukit.common.model.update_media_localized_data import \
    UpdateMediaLocalizedData


class UpdateDataUtil:
    @staticmethod
    def update_multi_language_data(media_localized_data: MediaLocalizedData,
                                   request_sender: EduKitRequestSender):
        update_media_localized_data = UpdateMediaLocalizedData()
        update_media_localized_data.media_type \
            = media_localized_data.media_type
        update_media_localized_data.height = media_localized_data.height
        update_media_localized_data.width = media_localized_data.width
        update_media_localized_data.media_len = media_localized_data.media_len
        update_media_localized_data.ordinal = media_localized_data.ordinal

        upload_frame_img_result = UpdateDataUtil.upload_frame_image(
            media_localized_data, request_sender)

        if not upload_frame_img_result:
            return False

        if isinstance(upload_frame_img_result, str):
            update_media_localized_data.frame_id = upload_frame_img_result

        try:
            upload_media_result = UpdateDataUtil.upload_media(
                media_localized_data, request_sender)
        except EduKitException:
            return False

        if not upload_media_result:
            return False

        if isinstance(upload_media_result, dict):
            update_media_localized_data.meida_id = upload_media_result[
                'materialId']
            update_media_localized_data.file_name = Helpers.get_file_base_name(
                upload_media_result['path'])
            update_media_localized_data.size = Helpers.get_file_size(
                upload_media_result['path'])
            update_media_localized_data.sha256 = Helpers.get_sha256(
                upload_media_result['path'])

        return update_media_localized_data

    @staticmethod
    def upload_frame_image(media_localized_data: MediaLocalizedData,
                           request_sender: EduKitRequestSender):
        if not media_localized_data.frame_image_file_info:
            return True
        try:
            file_upload = FileUpload(
                path=media_localized_data.frame_image_file_info.path,
                resource_type=FileUploadConstant.
                RESOURCE_TYPE['PROMOTIONAL_VIDEO_POSTER'],
                request_sender=request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload frame image failed. errMsg: {}'.format(
                str(e)))
            return False
        if not Helpers.is_success(result):
            logging.error('Upload frame image failed. errMsg: {}'.format(
                result['result']['resultDesc']))
            return False

        return result['materialId']

    @staticmethod
    def upload_media(media_localized_data: MediaLocalizedData,
                     request_sender: EduKitRequestSender):
        if not media_localized_data.media_file_info:
            return True
        public_file = False
        if media_localized_data.media_type == CommonConstant.MEDIA_TYPE[
                'COURSE_INTRODUCTION_VIDEO']:
            public_file = True
        try:
            file_upload = FileUpload(
                path=media_localized_data.media_file_info.path,
                file_type=media_localized_data.media_file_info.file_type,
                public_file=public_file,
                request_sender=request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload media failed. errMsg: {}'.format(str(e)))
            return False

        if not Helpers.is_success(result):
            logging.error('Upload media failed. errMsg: {}'.format(
                result['result']['resultDesc']))
            return False

        return {
            'path': media_localized_data.media_file_info.path,
            'materialId': result['materialId']
        }



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.http.client_response import ClientResponse


class HttpCommonResponse:
    def __init__(self, source_response: ClientResponse):
        if source_response and source_response.get_error():
            raise EduKitException(source_response.get_error())
        if source_response:
            self._response = source_response.get_rsp()
            self._headers = source_response.get_headers()
        else:
            raise EduKitException("Request failed!")

    def get_rsp(self):
        return self._response

    def get_headers(self):
        return self._headers



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CourseConstant:
    RESULT = 'result'
    RESULT_DESC = 'resultDesc'
    RESULT_CODE = 'resultCode'

    COURSE_STATUS_RESPONSE = 'edukit_sdk.edukit.course.resp.' \
                             'course_status_response.CourseStatusResponse'
    CREATE_COURSE_RESULT = 'edukit_sdk.edukit.course.impl.' \
                           'create_course_result.CreateCourseResult'

    COURSE_AUDIO_FILE = 'COURSE_AUDIO_FILE'
    COURSE_VIDEO_FILE = 'COURSE_VIDEO_FILE'

    MATERIAL_Id = 'materialId'
    PATH = 'path'

    COURSE_PACKAGE_HORIZONTAL_COVER = 'COURSE_PACKAGE_HORIZONTAL_COVER'
    COURSE_PORTRAIT_COVER = 'COURSE_PORTRAIT_COVER'
    COURSE_PACKAGE_INTRODUCTION = 'COURSE_PACKAGE_INTRODUCTION'
    PROMOTIONAL_VIDEO_POSTER = 'PROMOTIONAL_VIDEO_POSTER'
    COURSE_INTRODUCTION_VIDEO = 'COURSE_INTRODUCTION_VIDEO'
    CANCEL_COMMIT = 'CANCEL_COMMIT'
    COURSE_Id = 'courseId'
    COURSE_EDIT_ID = 'courseEditId'



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.course.constant.course_constant import CourseConstant
from edukit_sdk.edukit.course.impl.change_course_status_request import \
    ChangeCourseStatusRequest
from edukit_sdk.edukit.course.impl.course_handler import CourseHandler
from edukit_sdk.edukit.course.impl.create_course_result import \
    CreateCourseResult
from edukit_sdk.edukit.course.model.course_edit import CourseEdit
from edukit_sdk.edukit.course.resp.course_update_response import \
    CourseUpdateResponse


class CourseUpdateRequest:
    def __init__(self, course_edit: CourseEdit, credential_list):
        self._course_edit = course_edit
        self._course_handler = CourseHandler(
            EduKitRequestSender(credential_list))
        self._update_course_edit_id = None

    def save_draft(self):
        course_id = None
        if self.is_course_id_valid(self._course_edit):
            course_id = self._course_edit.course.course_id
        update_course_response = CourseUpdateResponse()

        if not course_id:
            logging.error('CourseId can not be null when update course data.')
            update_course_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return update_course_response

        logging.info('UpdateCourse save_draft task start and courseId:%s' %
                     course_id)
        update_course_edit_result = self.update_course_edit(self._course_edit)
        if not update_course_edit_result:
            update_course_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return update_course_response

        logging.info('UpdateCourse save_draft task end and courseId:%s' %
                     course_id)
        update_course_response.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)
        return update_course_response

    def commit(self, action):
        change_course_status_request = ChangeCourseStatusRequest(action=action)
        if action == CommonConstant.COURSE_COMMIT_ACTION[
                CourseConstant.CANCEL_COMMIT]:
            return self.cancel_course_commit(change_course_status_request)
        else:
            return self.handle_course(change_course_status_request)

    def cancel_course_commit(
            self, change_course_status_request: ChangeCourseStatusRequest):
        logging.info('COURSE_CANCEL_COMMIT action start.')
        course_update_response = CourseUpdateResponse()
        if not self._course_edit or not self._course_edit.course:
            logging.error(
                'CourseId can not be null when cancelling course commit.')
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return course_update_response

        if not self.is_course_id_valid(self._course_edit):
            logging.error(
                'CourseId can not be null when cancelling course commit.')
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return course_update_response

        course_id = self._course_edit.course.course_id

        course_edit_id = None
        if self._course_edit.course_edit_id:
            course_edit_id = self._course_edit.course_edit_id

        if not course_id or not course_edit_id:
            logging.error(
                'Course EditId is null when cancelling course commit.')
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_CANCEL_COMMIT_ACTION)
            return course_update_response

        course_update_response.course_id = course_id
        course_update_response.edit_id = course_edit_id
        course_update_response.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)

        course_update_response = self.course_commit(
            course_update_response, change_course_status_request)

        logging.info('COURSE_CANCEL_COMMIT action end and courseId:%s' %
                     course_id)
        return course_update_response

    def handle_course(self,
                      change_course_status_request: ChangeCourseStatusRequest):
        course_update_response = CourseUpdateResponse()
        if not self.is_course_id_valid(self._course_edit):
            logging.error('CourseId can not be null when update course data.')
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return course_update_response

        course_id = self._course_edit.course.course_id

        logging.info('UpdateCourse commit task start and courseId:%s' %
                     course_id)

        update_course_edit_result = self.update_course_edit(self._course_edit)

        if not update_course_edit_result:
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return course_update_response

        course_update_response.course_id = update_course_edit_result[
            CourseConstant.COURSE_Id]
        course_update_response.edit_id = update_course_edit_result[
            CourseConstant.COURSE_EDIT_ID]
        course_update_response.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)

        course_update_response = self.course_commit(
            course_update_response, change_course_status_request)
        logging.info('UpdateCourse commit task end and courseId:%s' %
                     course_id)
        return course_update_response

    def create_new_edit(self):
        return self._course_handler.create_new_course_edit(self._course_edit)

    def update_course_edit(self, course_edit: CourseEdit):
        if self.need_create_new_edit(course_edit):
            new_course_edit = self._course_handler.create_new_course_edit(
                course_edit)
            if new_course_edit.result.result_code != \
                    CommonConstant.RESULT_SUCCESS:
                logging.error(
                    'Get wrong result from create courseNewEdit interface '
                    'and courseId:%s,wrong result:%s'
                    % (course_edit.course.course_id,
                       new_course_edit.result.result_desc))
                return False
            edit_id = new_course_edit.edit_id
        else:
            edit_id = course_edit.course_edit_id

        create_course_result = CreateCourseResult(
            edit_id=edit_id, course_id=course_edit.course.course_id)

        if not self._course_handler.update_course_edit(course_edit,
                                                       create_course_result):
            return False

        return {
            CourseConstant.COURSE_Id: course_edit.course.course_id,
            CourseConstant.COURSE_EDIT_ID: edit_id
        }

    def course_commit(self, course_update_response: CourseUpdateResponse,
                      change_course_status_request: ChangeCourseStatusRequest):
        commit_result = self._course_handler.commit_course(
            course_update_response.course_id, course_update_response.edit_id,
            self._course_edit.course, change_course_status_request)

        if commit_result and commit_result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            course_update_response.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)

        course_update_response.commit_result = commit_result
        return course_update_response

    @staticmethod
    def need_create_new_edit(course_edit: CourseEdit):
        return False if course_edit.course_edit_id else True

    @staticmethod
    def is_course_id_valid(course_edit: CourseEdit):
        return True if course_edit and course_edit.course and \
                       course_edit.course.course_id else False



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.package.impl.pkg_handler import PkgHandler


class PkgCreateRequest:
    def __init__(self, pkg, credential_list):
        self._pkg = pkg
        self._pkg_handler = PkgHandler(EduKitRequestSender(credential_list))

    def create(self):
        self._pkg_handler.covert_localized_datas(self._pkg)
        return self._pkg_handler.create_pkg(self._pkg)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class LessonLocalizedData:
    def __init__(self):
        self._name = None
        self._deep_link_url = None

    @property
    def name(self):
        """
        :return:mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        设置章节名称。
        对于每种已添加的语言类型，章节提交前必须指定此字段。后续更新时也要携带此字段。
        :param name:
        """
        self._name = name

    @property
    def deep_link_url(self):
        """
        :return:mixed
        """
        return self._deep_link_url

    @deep_link_url.setter
    def deep_link_url(self, deep_link_url):
        """
        设置从教育中心客户端跳转到您的APP的DeepLink链接。
        如果用户需要跳转到您的APP（eduappUsed=false）学习此章节，在章节首次提交前必须提供此链接。如课程支持在教育中心学习，则此字段为可选。
        章节版本更新时可不携带此字段，此时将保留当前值不变。
        提供此字段时，需要同时提供residentAGApp字段，以便能正确拉起您的APP。
        此链接仅用于学习章节内容时跳转，如果用户购买课程时需要跳转到您的APP，应设置课程元数据中的deepLink参数。
        可以在此链接中增加必要的参数以辅助跳转后在您的APP内的逻辑处理，教育中心将透传这些参数。但请勿在链接中携带敏感数据（如用户密码等）。
        :param deep_link_url:
        """
        self._deep_link_url = deep_link_url

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class LessonMultiLanguageData:
    def __init__(self):
        self._language = None
        self._lesson_localized_data = None
        self._media_localized_data = None

    @property
    def language(self):
        """
        :return:mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        设置章节语言信息。
        语言代码由BCP-47定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母）。
        :param language:
        """
        self._language = language

    @property
    def lesson_localized_data(self):
        """
        :return:mixed
        """
        return self._lesson_localized_data

    @lesson_localized_data.setter
    def lesson_localized_data(self, lesson_localized_data):
        """
        设置章节本地化多语言数据。
        :param lesson_localized_data:
        """
        self._lesson_localized_data = lesson_localized_data

    @property
    def media_localized_data(self):
        """
        :return:mixed
        """
        return self._media_localized_data

    @media_localized_data.setter
    def media_localized_data(self, media_localized_data):
        """
        设置章节媒体文件。
        :param media_localized_data:
        """
        self._media_localized_data = media_localized_data



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class UpdateAlbumResponse(Response):
    def __init__(self):
        self._result = None
        self._album_id = None
        self._edit_id = None
        self._edit_result = None
        self._delete_localized_result = None
        self._error_course_list = None
        self._error_sub_album_list = None

    @property
    def result(self):
        """
        :return:mixed
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        :param result:
        :return:
        """
        self._result = result

    @property
    def album_id(self):
        """
        :return:mixed
        """
        return self._album_id

    @album_id.setter
    def album_id(self, album_id):
        """
        更新成功的专辑ID
        :param album_id:
        :return:
        """
        self._album_id = album_id

    @property
    def edit_id(self):
        """
        :return:mixed
        """
        return self._edit_id

    @edit_id.setter
    def edit_id(self, edit_id):
        """
        更新成功的Edit ID，后续调用接口更新专辑版本信息时，需要提供该ID
        :param edit_id:
        :return:
        """
        self._edit_id = edit_id

    @property
    def edit_result(self):
        """
        :return:mixed
        """
        return self._edit_result

    @edit_result.setter
    def edit_result(self, edit_result):
        """
        :param edit_result:
        :return:
        """
        self._edit_result = edit_result

    @property
    def delete_localized_result(self):
        """
        :return:mixed
        """
        return self._delete_localized_result

    @delete_localized_result.setter
    def delete_localized_result(self, delete_localized_result):
        """
        :param delete_localized_result:
        :return:
        """
        self._delete_localized_result = delete_localized_result

    @property
    def error_course_list(self):
        """
        :return:mixed
        """
        return self._error_course_list

    @error_course_list.setter
    def error_course_list(self, error_course_list):
        """
        添加失败的课程ID列表信息，最大2000个
        :param error_course_list:
        :return:
        """
        self._error_course_list = error_course_list

    @property
    def error_sub_album_list(self):
        """
        :return:mixed
        """
        return self._error_sub_album_list

    @error_sub_album_list.setter
    def error_sub_album_list(self, error_sub_album_list):
        """
        添加失败的子专辑列表信息，最大20个
        :param error_sub_album_list:
        :return:
        """
        self._error_sub_album_list = error_sub_album_list



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os

from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant


class Config:
    def get_config(self):
        rsp = dict()
        path = os.path.join(CommonConstant.ROOT_PATH,
                            CommonConstant.CONFIG_DIR, 'edukit_config.ini')
        config_str = self.file_get_contents(path)
        config_list = config_str.split(';')
        for config in config_list:
            single_config_list = config.split('=')
            if single_config_list[0] and single_config_list[1].strip():
                eventually_key = single_config_list[0].strip().replace(
                    '.', '_').upper()
                rsp[eventually_key] = single_config_list[1].strip()
        return rsp

    def get_domain(self):
        return self.get_config().get(ClientConstant.SERVER_DOMAIN)

    # 将文件内容读取到一个字符串中
    @staticmethod
    def file_get_contents(path):
        data = ''
        with open(path, 'r') as f:
            for line in f.readlines():
                line = line.strip()
                data += line
        return data



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class LessonConstant:
    CreateLessonResult = 'edukit_sdk.edukit.lesson.impl.' \
                         'create_lesson_result.CreateLessonResult'
    RESPONSE = 'edukit_sdk.edukit.common.model.response.Response'
    UPDATE_LESSON_RESULT = 'edukit_sdk.edukit.lesson.impl.' \
                           'update_lesson_result.UpdateLessonResult'



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.lesson.impl.lesson_handler import LessonHandler
from edukit_sdk.edukit.lesson.resp.lesson_create_response import \
    LessonCreateResponse


class LessonCreateRequest:
    def __init__(self, course_id, course_edit_id, lesson, credential_list):
        self._course_id = course_id
        self._course_edit_id = course_edit_id
        self._lesson = lesson
        self._lesson_handler = LessonHandler(
            EduKitRequestSender(credential_list))

    def create_lesson(self):
        rsp = LessonCreateResponse()
        if Helpers.has_empty_param([self._course_id, self._course_edit_id]):
            logging.error(
                'CourseId or CourseEditId can not be null when create lesson.')
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return rsp
        logging.info('Create lesson begin, courseId = %s, courseEditId = %s' %
                     (self._course_id, self._course_edit_id))
        create_lesson_result = self._lesson_handler.create_lesson(
            self._course_id, self._course_edit_id, self._lesson)
        rsp.result = create_lesson_result.result

        if create_lesson_result and create_lesson_result and \
                create_lesson_result.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            logging.error('Create Lesson failed and code:%s result:%s' %
                          (create_lesson_result.result.result_code,
                           create_lesson_result.result.result_desc))
            return rsp

        lesson_id = create_lesson_result.lesson_id
        lesson_edit_id = create_lesson_result.lesson_edit_id

        rsp.lesson_id = lesson_id
        rsp.lesson_edit_id = lesson_edit_id

        return self._lesson_handler.update_lesson_data_create(
            self._course_id, self._course_edit_id, lesson_id, lesson_edit_id,
            self._lesson, rsp)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ApiConstant:
    # 请求接口
    TOKEN_URL = '/api/edukit/aps/v1/token'
    # UPLOAD
    UPLOAD_RESOURCE_URL = '/api/edukit/v1/resource/upload'
    APPLY_UPLOAD_URL = '/api/edukit/v1/media/uploadUrl'
    MULTIPART_PARTS_URL = '/api/edukit/v1/media/multipartParts'
    MULTIPART_COMPOSE_URL = '/api/edukit/v1/media/multipartCompose'
    # COURSE
    CREATE_COURSE_URL = '/api/edukit/v1/course'
    UPDATE_META_COURSE_URL = '/api/edukit/v1/course/metadata/{}/{}'
    UPDATE_PRICE_COURSE_URL = '/api/edukit/v1/course/productPrice/{}'
    UPDATE_LOCALIZED_COURSE_URL = '/api/edukit/v1/course' \
                                  '/localizedData/{}/{}/{}'
    COMMIT_COURSE_URL = '/api/edukit/v1/course/commit/{}/{}'
    CREATE_NEW_COURSE_EDIT_URL = '/api/edukit/v1/course/edit/{}'
    DELETE_COURSE_URL = '/api/edukit/v1/course/localizedData/{}/{}/{}'
    REMOVE_COURSE_URL = '/api/edukit/v1/course/removal/{}'
    GET_COURSE_STATUS_URL = '/api/edukit/v1/course/status/{}'
    # LESSON
    LESSON_CREATE_URL = '/api/edukit/v1/lesson/{}/{}'
    LESSON_URL = '/api/edukit/v1/lesson/{}/{}/{}'
    LESSON_METADATA_URL = '/api/edukit/v1/lesson' \
                          '/metadata/{}/{}/{}/{}'
    LESSON_LOCALIZED_DATA_URL = '/api/edukit/v1/lesson' \
                                '/localizedData/{}/{}/{}/{}/{}'
    LESSON_RESET_URL = '/api/edukit/v1/lesson/reset/{}/{}/{}'
    # TEACHER
    CREATE_TEACHER_URL = '/api/edukit/v1/teacher'
    UPDATE_META_TEACHER_URL = '/api/edukit/v1/teacher/metadata/{}/{}'
    UPDATE_LOCALIZED_TEACHER_URL = '/api/edukit/v1/teacher' \
                                   '/localizedData/{}/{}/{}'
    COMMIT_TEACHER_URL = '/api/edukit/v1/teacher/commit'
    CREATE_NEW_TEACHER_EDIT_URL = '/api/edukit/v1/teacher/edit'
    DELETE_LOCALIZED_TEACHER_URL = '/api/edukit/v1/teacher/' \
                                   'localizedData/{}/{}/{}'
    DELETE_TEACHER_URL = '/api/edukit/v1/teacher/edit/{}/delete'
    # ALBUM
    CREATE_ALBUM_URL = '/api/edukit/v1/api/album'
    CREATE_UPDATE_ALBUM_URL = '/api/edukit/v1/api/album/{}'
    MANAGE_ALBUM_STATUS_URL = '/api/edukit/v1/album/manage/{}'
    DELETE_ALBUM_URL = '/api/edukit/v1/album/{}'
    # NEW PKG
    CREATE_PKG_URL = '/api/edukit/v1/api/pkg'
    UPDATE_PKG_URL = '/api/edukit/v1/api/pkg/{}'
    MANAGE_PKG_STATUS_URL = '/api/edukit/v1/pkg/manage/{}'
    DELETE_PKG_URL = '/api/edukit/v2/pkg/{}'
    UPDATE_PACKAGE_PRODUCT_URL = '/api/edukit/v2/pkg/product/{}'
    DELETE_PACKAGE_PRODUCT_URL = '/api/edukit/v2/pkg/product' \
                                 '/{}?pkgEditId={}&productId={}'
    # SIGNUP
    REPORT_SIGNUP = "/api/edukit/v1/{}/{}/signup?userIdType={}"
    REPORT_SIGNUP_PACKAGE = "/api/edukit/v1/{}/package/signup?userIdType={}"
    BATCH_REPORT_SIGNUP_COURSE = "/api/edukit/v1/{}/signup/batch?userIdType={}"
    # LEARNING
    REPORT_UNITARY_COURSE_LEARNING = "/api/edukit/v1/{}/{}/" \
                                     "learning?userIdType={}"
    REPORT_SERIES_COURSE_LEARNING = "/api/edukit/v1/{}/{}/{}/" \
                                    "learning?userIdType={}"
    # CATALOGUE
    CREATE_CATALOGUE_URL = '/api/edukit/v1/catalogue/{}/{}'
    UPDATE_CATALOGUE_URL = '/api/edukit/v1/catalogue/{}/{}/{}'
    DELETE_CATALOGUE_URL = '/api/edukit/v1/catalogue/{}/{}/{}'



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class Pkg:
    def __init__(self):
        self._action = None
        self._associate_album_id = None
        self._edit = None

    @property
    def action(self):
        """
        :return:mixed
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        创建时的操作，1-提交审核
        :param action:
        :return:
        """
        self._action = action

    @property
    def associate_album_id(self):
        """
        :return:mixed
        """
        return self._associate_album_id

    @associate_album_id.setter
    def associate_album_id(self, associate_album_id):
        """
        关联的专辑ID
        :param associate_album_id:
        :return:
        """
        self._associate_album_id = associate_album_id

    @property
    def edit(self):
        """
        :return:mixed
        """
        return self._edit

    @edit.setter
    def edit(self, edit):
        """
        会员包版本数据
        :param edit:
        :return:
        """
        self._edit = edit

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os
import uuid

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.error_constant import ErrorConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.constant.http_constant import HttpConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse


def build_form_data(form_data: dict):
    """
    生成上传文件所需的form-data格式
    :param form_data: 传入的需要上传的字典
    :return:bytes
    """
    delimiter = str(uuid.uuid1()).replace('-', '')  # 将uuid转化为字符串
    headers = {
        HttpConstant.CONTENT_TYPE: 'multipart/form-data; boundary=' + delimiter
    }

    data1 = ''
    eol = os.linesep
    file_content = form_data.get('file')
    if file_content:
        del form_data['file']
    for name, content in form_data.items():
        data1 += "--" + delimiter + eol + \
                 'Content-Disposition: form-data; name="' \
                 + name + '"' + eol + eol \
                 + str(content) + eol
    # 拼接文件流
    data1 += "--" + delimiter + eol + \
             'Content-Disposition: form-data; name="file"; filename="' + \
             form_data.get(
                 ClientConstant.FILE_NAME) + '"' \
             + eol + 'Content-Type:application/octet-stream' \
             + eol + eol

    data3 = eol + "--" + delimiter + "--" + eol
    body = bytes(data1, ClientConstant.UTF_8) + file_content + bytes(
        data3, ClientConstant.UTF_8)
    # 返回二进制数据
    return body, headers


class UploadPicture:
    def __init__(self, file_request, request_sender):
        self._file_request = file_request
        self._request_sender = request_sender

    def upload(self):
        url = ApiConstant.UPLOAD_RESOURCE_URL
        # 获取图片后缀
        suffix = os.path.splitext(self._file_request.path)[-1]
        # 图片格式只能是jpg,png中的一种
        if suffix not in FileUploadConstant.PICTURE_SUFFIX:
            raise EduKitException('Upload failed! ErrorMessage:{}'.format(
                ErrorConstant.PICTURE_FILE_TYPE_ERROR))

        # 将图片读取为二进制数据
        with open(self._file_request.path, ClientConstant.RB) as f:
            file = f.read()
            form_data = {
                ClientConstant.FILE_SIZE: self._file_request.file_size,
                ClientConstant.FILE_SHA256: self._file_request.sha256,
                ClientConstant.RESOURCE_TYPE: self._file_request.resource_type,
                ClientConstant.FILE_NAME: self._file_request.file_name,
                ClientConstant.FILE: file
            }
            body, headers = build_form_data(form_data)
        try:
            rsp = HttpCommonResponse(
                self._request_sender.post(url=url, body=body, headers=headers))
        except EduKitException as e:
            raise EduKitException(e.message)

        return rsp.get_rsp()



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.errorcode.teacher_error_code import \
    TeacherErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.teacher.impl.teacher_handler import TeacherHandler
from edukit_sdk.edukit.teacher.model.teacher import Teacher
from edukit_sdk.edukit.teacher.resp.teacher_create_response import \
    TeacherCreateResponse


class TeacherCreateRequest:
    def __init__(self, teacher: Teacher, credential_list):
        self._teacher = teacher
        self._teacher_handler = TeacherHandler(
            EduKitRequestSender(credential_list))

    def save_draft(self):
        teacher_create_rsp = TeacherCreateResponse()
        logging.info('Create teacher begin')
        create_teacher_result = self._teacher_handler.create_teacher(
            self._teacher)
        if create_teacher_result.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            logging.error('Create teacher failed and result:%s' %
                          create_teacher_result.result.result_desc)
            teacher_create_rsp.teacher_create_result = \
                create_teacher_result.result
            teacher_create_rsp.result = Helpers.build_error_result(
                CommonErrorCode.NO_SUCCESSFUL_OPERATION)
            return teacher_create_rsp

        teacher_create_rsp.teacher_id = create_teacher_result.teacher_id
        teacher_create_rsp.teacher_edit_id = create_teacher_result.edit_id
        if not self._teacher.teacher_multi_language_data_list and not \
                self._teacher.teacher_metadata:
            logging.info(
                'An empty teacher is created and teacherId:%s, editId:%s.' %
                create_teacher_result.teacher_id,
                create_teacher_result.edit_id)
            teacher_create_rsp.result = Helpers.build_error_result(
                CommonErrorCode.SUCCESS)
            return teacher_create_rsp

        update_teacher_result = self._teacher_handler.update_teacher(
            self._teacher, create_teacher_result)
        teacher_create_rsp.teacher_create_result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)
        teacher_create_rsp.update_metadata_result = \
            update_teacher_result.update_metadata_result
        teacher_create_rsp.update_localized_data_result = \
            update_teacher_result.update_localized_data_result
        teacher_create_rsp.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)
        if (update_teacher_result.update_metadata_result.result_code !=
                CommonConstant.RESULT_SUCCESS or
                update_teacher_result.update_localized_data_result.result_code
                != CommonConstant.RESULT_SUCCESS):
            teacher_create_rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)

        return teacher_create_rsp

    def commit(self):
        teacher_create_rsp = TeacherCreateResponse()
        if not self._teacher.teacher_metadata:
            logging.error(
                'Teacher metaData can not be null when creating teacher '
                'to commit.'
            )
            teacher_create_rsp.result = Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_MATA_DATA)
            return teacher_create_rsp

        if not self._teacher.teacher_multi_language_data_list:
            logging.error(
                'Teacher localizedData can not be null when creating teacher '
                'to commit.'
            )
            teacher_create_rsp.result = Helpers.build_error_result(
                TeacherErrorCode.INVALID_TEACHER_PARAMS_LOCALIZED_DATA)
            return teacher_create_rsp

        create_teacher_result = self._teacher_handler.create_teacher(
            self._teacher)
        teacher_create_rsp.teacher_create_result = create_teacher_result.result
        if create_teacher_result.result.result_code != \
                CommonConstant.RESULT_SUCCESS:
            logging.error('Create teacher failed and result:%s' %
                          create_teacher_result.result)
            teacher_create_rsp.result = Helpers.build_error_result(
                CommonErrorCode.NO_SUCCESSFUL_OPERATION)
            return teacher_create_rsp

        update_teacher_result = self._teacher_handler.update_teacher(
            self._teacher, create_teacher_result)
        teacher_create_rsp.teacher_id = create_teacher_result.teacher_id
        teacher_create_rsp.teacher_edit_id = create_teacher_result.edit_id
        teacher_create_rsp.update_metadata_result = \
            update_teacher_result.update_metadata_result
        teacher_create_rsp.update_localized_data_result = \
            update_teacher_result.update_localized_data_result

        commit_result = self._teacher_handler.commit(
            create_teacher_result.teacher_id, create_teacher_result.edit_id)
        teacher_create_rsp.teacher_commit_result = commit_result
        teacher_create_rsp.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)
        if commit_result.result_code != CommonConstant.RESULT_SUCCESS:
            teacher_create_rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARTIAL_SUCCESS)

        return teacher_create_rsp



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class Products:
    def __init__(self):
        self._products = None

    @property
    def products(self):
        """
        :return: mixed
        """
        return self._products

    @products.setter
    def products(self, products):
        """
        商品列表信息
        :param products:
        :return:
        """
        self._products = products

    def to_json_string(self):
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class LessonMetaData:
    def __init__(self):
        self._name = None
        self._default_lang = None
        self._free_flag = None
        self._available_from = None
        self._available_before = None
        self._display_order = None
        self._edu_app_used = None
        self._media_type = None

    @property
    def default_lang(self):
        """
        :return:mixed
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """
        设置默认语言。
        您可以提供多语言的章节信息，教育中心客户端向用户展示章节时，会优先匹配用户设备设置的系统语言。如您未提供用户系统语言对应的章节信息，将展示默认语言对应的数据。
        您必须提供默认语言对应的章节信息。
        章节首次提交审核前必须指定此字段；后续更新时如不指定此字段则保留当前值。
        当前华为教育中心仅在中国大陆地区提供服务，默认语言建议设置为简体中文(“zh-CN”)。
        语言代码由BCP-47定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母）。
        :param default_lang:
        """
        self._default_lang = default_lang

    @property
    def free_flag(self):
        """
        :return:mixed
        """
        return self._free_flag

    @free_flag.setter
    def free_flag(self, free_flag):
        """
        设置是否免费章节标记。
        章节首次提交时，必须通过此字段指定是否为免费章节。后续更新时可不携带此字段，此时将保留当前值不变。
        只       有付费课程允许有付费章节；如果课程本身为免费，此字段将被忽略。
        true-免费
        false-付费
        如果选择付费章节，须确保开发者账号已完成商户认证，否则无法提交成功。
        :param free_flag:
        """
        self._free_flag = free_flag

    @property
    def available_from(self):
        """
        :return:mixed
        """
        return self._available_from

    @available_from.setter
    def available_from(self, available_from):
        """
        设置章节最早可用时间。
        该时间必须晚于当前时间。考虑到服务器时间可能存在差异，应尽量避免指定距离当前时间过近的时间。
        该字段当前主要用于直播类课程，指定直播开始时间。直播课程的章节必须携带；非直播类课程可不指定此时间。
        首次提交设置此时间后，后续更新时可不携带此字段，此时将保留当前值不变。
        直播课直        播时间过后将自动变为视频课，无需再更新此时间。
        时间格式使用RFC3339定义的UTC时间格式（即GMT+00时区的时间），例：2021-12-20T08:00:00Z。
        :param available_from:
        """
        self._available_from = available_from

    @property
    def available_before(self):
        """
        :return:mixed
        """
        return self._available_before

    @available_before.setter
    def available_before(self, available_before):
        """
        设置章节最晚可用时间。
        该时间必须必须晚于课程最早可用时间（availableFrom字段）。
        该字      段当前主要用于直播类课程，指定直播结束时间。直播课程的章节必须携带；非直播类课程可不指定此时间。
        首次提交设置此时间后，后续更新时可不携带此字段，此时将保留当前值不变。
        直播课直播时间过后将自动变为视频课，无需再更新此时间。
        :param available_before:
        """
        self._available_before = available_before

    @property
    def display_order(self):
        """
        :return:mixed
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """
        设置章节序号。
        同一课程        章节列表中该章节的排列顺序，例如：1表示当前章节排在所属课程章节列表的第一个。
        该序号用于控制章节在课程目录列表中的展示顺序；序号越小展示越靠前。
        如未指定该字段，创建课程时将从100开始取当前章节序号最大值+1作为新建章节的序号；更新章节时当前序号不变（更新章节版本元数据时可以修改）。
        该序号不直接向用户展示，只作为排序依据。因此建议章节序号之间保留一定的间隙，以应对需要在两个章节之间插入新章节的场景。
        取值范围：0~9999。
        :param display_order:
        """
        self._display_order = display_order

    @property
    def edu_app_used(self):
        """
        :return:mixed
        """
        return self._edu_app_used

    @edu_app_used.setter
    def edu_app_used(self, edu_app_used):
        """
        设置章节是否支持在教育中心中学习标记。
        对       于视频/音频类课程，将音视频文件上传到教育中心后，可以设置为true，支持在教育中心学习，由教育中心客户端直接播放。
        如设置为false，用户在教育中心学习该章节时，将通过DeepLink拉起课程元数据中residentAGApp字段对应的应用。
        章节首次提交审核前必须指定此字段；课程审核通过上架后，此字段将不能再修改。
        同一课程的不同章节，可以设置不同的属性值。
        :param edu_app_used:
        """
        self._edu_app_used = edu_app_used

    @property
    def media_type(self):
        """
        :return:mixed
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        设置章节媒体类型。
        如果课程类型为绘本，该字段必填。
        支持的取值如下：
        1：音频
        2：视频
        3：绘本
        :param media_type:
        """
        self._media_type = media_type

    @property
    def name(self):
        """
        :return:mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        设置默认语言对应的章节名称。
        需要与章节多语言数据中defaultLang对应语言的名称相同。
        章节首次提交前必须指定此字段；后续更新时如不指定此字段则保留当前值。
        :param name:
        """
        self._name = name



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.album.impl.album_handler import AlbumHandler
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class AlbumDeleteRequest:
    def __init__(self, album_id, credential_list):
        self.__album_id = album_id
        self.__album_handler = AlbumHandler(
            EduKitRequestSender(credential_list))

    def delete(self):
        return self.__album_handler.delete_album(self.__album_id)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json
import logging
import math
import os
import shutil
import time
import uuid

from edukit_sdk.edukit.common.config.config import Config
from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.constant.error_constant import ErrorConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.constant.http_constant import HttpConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload_request import \
    FileUploadRequest
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse


def tuple2_to_dict(lists: list):
    # 将返回头列表中的二元元组转化为字典列表
    headers_list = []
    if lists:
        for dict2 in lists:
            list_dict = []
            mydict = dict2.get(ClientConstant._HEADERS)
            if mydict:
                for item in mydict:
                    d = {item[0]: item[1]}
                    list_dict.append(d)
                dict2[ClientConstant._HEADERS] = list_dict
                headers_list.append(dict2)
    return headers_list


# 获取返回头列表中字典元素指定key的value
def get_list_dict_value(list_table: list, p_key):
    if list_table:
        for header in list_table:
            (key, value), = header.items()
            if key == p_key:
                return value


class UploadMedia:
    def __init__(self, file_request: FileUploadRequest,
                 request_sender: EduKitRequestSender):
        self._file_request = file_request
        config = Config()
        self._part_size = int(config.get_config().get(
            ClientConstant.PART_MAXSIZE))
        self._request_sender = request_sender

    def upload(self):
        suffix = os.path.splitext(self._file_request.path)[-1]
        if suffix not in FileUploadConstant.FILE_SUFFIX:
            raise EduKitException('Upload failed! ErrorMessage:{}'
                                  .format(ErrorConstant.MEDIA_FILE_TYPE_ERROR))
        apply_rsp = self.apply_upload_url()
        try:
            if self.is_multi_part(apply_rsp):
                # 需要分片,分片上传
                self.upload_file_parts(apply_rsp)
            else:
                logging.info('Uploading file ' + self._file_request.file_name)
                # 不需要分片,一次性上传文件
                self.upload_file(apply_rsp, self._file_request.path)
                logging.info('Uploading file ' + self._file_request.file_name +
                             ' success')
        except EduKitException as e:
            raise EduKitException("Upload failed! ErrorMessage:{}"
                                  .format(str(e)))
        return apply_rsp

    @staticmethod
    def is_multi_part(apply_rsp):
        return True if apply_rsp.get(ClientConstant.MULTI_PART_FLAG) else False

    def apply_upload_url(self):
        """
        申请文件上传地址
        :return:mixed
        """
        url = ApiConstant.APPLY_UPLOAD_URL
        body = {
            ClientConstant.FILE_NAME: self._file_request.file_name,
            ClientConstant.FILE_TYPE: self._file_request.file_type,
            ClientConstant.FILE_SIZE: self._file_request.file_size,
            ClientConstant.FILE_SHA256: self._file_request.sha256,
            ClientConstant.PUBLIC_FILE: self._file_request.public_file,
        }
        body = bytes(json.dumps(body), encoding=ClientConstant.UTF_8)
        headers = {HttpConstant.CONTENT_TYPE: HttpConstant.APPLICATION_JSON}
        rsp = HttpCommonResponse(
            self._request_sender.post(url=url, body=body, headers=headers))
        return rsp.get_rsp()

    def upload_file(self, apply_rsp, file_path):
        """
        不分片时一次性上传文件
        :param file_path: 要上传的文件地址
        :param apply_rsp: 申请上传文件返回的结果集包含上传地址,请求头,上传方法
        :return:mixed
        """
        url = apply_rsp.get(ClientConstant.TMP_UPLOAD_URL)
        headers = json.loads(apply_rsp.get(ClientConstant.UPLOAD_HEADERS))
        method = apply_rsp.get(ClientConstant.UPLOAD_METHOD)
        with open(file_path, ClientConstant.RB) as f:
            file = f.read()
        try:
            rsp = HttpCommonResponse(
                self._request_sender.upload_once(url=url,
                                                 headers=headers,
                                                 body=file,
                                                 method=method))
        except EduKitException as e:
            raise EduKitException('Upload failed! ErrorMessage:{}'
                                  .format(str(e)))
        return rsp.get_headers()

    def upload_file_parts(self, apply_rsp):
        """
        上传分片
        :param apply_rsp: 申请上传文件地址后的返回结果
        :return:
        """
        cache_rsp = self.part_file(apply_rsp.get(ClientConstant.MAX_PAER_SIZE))
        try:
            upload_start_time = time.time()
            # 获得分片上传信息列表
            part_upload_list = self.get_part_upload_list(
                apply_rsp.get(ClientConstant.FILE_ID), cache_rsp)
            # 上传分片文件
            part_upload_rsp_list = self.upload_file_list(
                part_upload_list.get(ClientConstant.FILE_PARTS), cache_rsp,
                apply_rsp.get(ClientConstant.FILE_ID), upload_start_time)
            # 分片合并
            response = self.multipart_compose(
                apply_rsp.get(ClientConstant.FILE_ID), part_upload_rsp_list)
            return response
        except EduKitException as e:
            raise EduKitException(
                'Compose file parts failed!, ErrorMessage:{}'.format(str(e)))
        finally:
            if os.path.exists(cache_rsp.get('cache_path')):
                shutil.rmtree(cache_rsp.get('cache_path'))

    def part_file(self, api_max_part_size):
        """
        将文件分片保存到缓存目录中
        :param api_max_part_size: 返回的最大分片size
        :return:
        """
        file_path = self._file_request.path
        chunk_size = self._part_size \
            if api_max_part_size \
               > self._part_size else api_max_part_size
        file_size = os.path.getsize(file_path)
        total_chunks = math.ceil(file_size / chunk_size)
        cache_id = str(uuid.uuid1()).replace("-", "")
        cache_path = CommonConstant.ROOT_PATH + \
                     FileUploadConstant.FILE_CACHE_DIR + cache_id
        os.makedirs(cache_path, CommonConstant.DIR_DEFAULT_MOD)

        for index in range(0, total_chunks):
            try:
                with open(file_path, ClientConstant.RB) as file:
                    file.seek(index * chunk_size, 0)
                    chunk = file.read(chunk_size)
                    chunk_cached_path = cache_path + os.sep + str(index)
                    with open(chunk_cached_path,
                              CommonConstant.FILE_MODE_CREATE_WRITE)\
                            as cached_file:
                        cached_file.write(chunk)
                    os.chmod(chunk_cached_path,
                             CommonConstant.FILE_DEFAULT_MOD)
            except Exception as e:
                raise EduKitException(
                    "Part file failed, ErrorMessage:{}".format(str(e)))

        logging.info('Part file {}'.format(self._file_request.file_name) +
                     ' to {}'.format(total_chunks) + ' parts.')
        return {'cache_path': cache_path, 'total_chunks': total_chunks}

    def upload_file_list(self, file_parts, cache_rsp, file_id,
                         upload_start_time):
        """
        * 上传分片文件
        * :param: fileParts 分片上传文件申请返回的分片文件信息集合
        * :param: cacheRsp 返回的最大分片大小
        * :param: fileId 申请上传地址返回的文件id
        * :param: uploadStartTime 上传开始时间
        """
        part_upload_rsp_list = []
        for index, file_part in enumerate(file_parts):
            # 当上传超过一定时间需要重新获取上传信息
            single_start_time = time.time()
            if self.is_upload_timeout(upload_start_time, single_start_time):
                part_upload_list = self.get_part_upload_list(
                    file_id, cache_rsp)
                file_parts = part_upload_list.get(ClientConstant.FILE_PARTS)
                upload_start_time = time.time()

            single_upload_info = {
                ClientConstant.TMP_UPLOAD_URL:
                    file_part.get(ClientConstant.MATERIAL_URL),
                ClientConstant.UPLOAD_HEADERS:
                    file_part.get('headers'),
                ClientConstant.UPLOAD_METHOD:
                    file_part.get('method')
            }

            logging.info('Uploading file part ' + str(index))
            try:
                single_rsp = self.upload_file(single_upload_info,
                                              (cache_rsp.get('cache_path') +
                                               os.sep + str(index))).__dict__
                part_object = {
                    ClientConstant.PART_OBJECT_ID:
                        file_part.get(ClientConstant.PART_OBJECT_ID)
                }
                # 合并两个字典
                part_upload_rsp_dict = single_rsp.copy()
                part_upload_rsp_dict.update(part_object)
                part_upload_rsp_list.append(part_upload_rsp_dict)
            except EduKitException as e:
                # 删除非空目录
                shutil.rmtree(cache_rsp.get('cache_path'))
                raise EduKitException(
                    'Upload file part {} failed!, ErrorMessage:{}'.format(
                        str(index + 1), str(e)))

        # 如果在上传分片超时,会重新获取分片上传信息,故将缓存数据放在最后删除
        shutil.rmtree(cache_rsp['cache_path'])
        part_upload_rsp_list = tuple2_to_dict(part_upload_rsp_list)
        return part_upload_rsp_list

    def get_part_upload_list(self, file_id, cache):
        """
            * 获得分片上传信息列表
            * :param: fileId
            * :param: cache
            * :return: HttpCommonResponse
           """
        chunk_list = []
        if cache.get('total_chunks'):
            for index in range(0, cache.get('total_chunks')):
                temp_path = cache.get('cache_path') + os.sep + str(index)
                chunk_dict = {
                    ClientConstant.FILE_SHA256: Helpers.get_sha256(temp_path),
                    ClientConstant.FILE_SIZE: os.path.getsize(temp_path)
                }
                # 将字典元素放入列表中
                chunk_list.append(chunk_dict)

        url = ApiConstant.MULTIPART_PARTS_URL
        body = {
            ClientConstant.FILE_PARTS: chunk_list,
            ClientConstant.FILE_ID: file_id
        }
        body = bytes(json.dumps(body), encoding=ClientConstant.UTF_8)
        headers = {HttpConstant.CONTENT_TYPE: HttpConstant.APPLICATION_JSON}
        rsp = HttpCommonResponse(
            self._request_sender.post(url=url, body=body, headers=headers))
        return rsp.get_rsp()

    @staticmethod
    def is_upload_timeout(upload_start_time, single_start_time):
        return single_start_time - upload_start_time > \
               FileUploadConstant.FILE_UPLOAD_LIMIT_TIME

    def multipart_compose(self, file_id, part_upload_rsp_list):
        """
        * 分片合并
        * :param: fileId:文件id
        * :param: part_upload_rsp_list 请求分片上传后的返回集合
        """
        url = ApiConstant.MULTIPART_COMPOSE_URL
        file_parts_list = []

        if part_upload_rsp_list:
            for part_rsp in part_upload_rsp_list:
                # 上一步骤接口返回数据多了引号'"'，封装数据时删除
                single_file_part = {
                    ClientConstant.PART_OBJECT_ID:
                        part_rsp.get(ClientConstant.PART_OBJECT_ID),
                    "etag":
                        get_list_dict_value(
                            part_rsp.get(ClientConstant._HEADERS),
                                            ClientConstant.E_TAG).strip('"'),
                    ClientConstant.GOOGLE_GENERATION:
                        ""
                }

                if part_rsp.get(ClientConstant.X_GOOGLE_GENERATION):
                    single_file_part[
                        ClientConstant.
                            GOOGLE_GENERATION] = get_list_dict_value(
                        part_rsp.get(ClientConstant._HEADERS),
                        ClientConstant.X_GOOGLE_GENERATION).strip('"')
                file_parts_list.append(single_file_part)
        body = {
            ClientConstant.FILE_ID: file_id,
            ClientConstant.FILE_PARTS: file_parts_list
        }
        body = bytes(json.dumps(body), encoding=ClientConstant.UTF_8)
        headers = {HttpConstant.CONTENT_TYPE: HttpConstant.APPLICATION_JSON}
        return HttpCommonResponse(
            self._request_sender.post(url=url, body=body, headers=headers))



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.model.response import Response


class SignupHandler:
    def __init__(self, request_sender):
        """
        :param request_sender:相关类
        """
        self.__request_sender = request_sender

    def report_signup(self, user_id, course_id, user_id_type, signup_info):
        """
        :param user_id:用户华为帐号ID
        :param course_id:课程ID
        :param user_id_type:user_id字段对应的帐号类型
        :param signup_info:相关类
        :return: response
        """
        logging.info(u"Call report_signup interface start, course_id: %s",
                     course_id)
        response = Response()
        try:
            url = ApiConstant.REPORT_SIGNUP.format(user_id, course_id,
                                                   user_id_type)
            http_common_response = HttpCommonResponse(
                self.__request_sender.put(url=url,
                                          body=signup_info.to_json_string()))
            response.result = Helpers.build_result(
                http_common_response.get_rsp())
        except EduKitException as e:
            logging.error(
                u'Call reportSignup interface failed. ErrorMessage: %s',
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info(u'Call reportSignup interface end, courseId: %s',
                     course_id)
        return response

    def report_signup_package(self, user_id, user_id_type,
                              package_signup_info):
        """
        :param user_id:用户华为帐号ID
        :param user_id_type:user_id字段对应的帐号类型
        :param package_signup_info:相关类
        :return: response
        """
        logging.info('Call reportSignupPackage interface start')
        response = Response()
        try:
            url = ApiConstant.REPORT_SIGNUP_PACKAGE.format(
                user_id, user_id_type)
            http_common_response = HttpCommonResponse(
                self.__request_sender.put(
                    url=url, body=package_signup_info.to_json_string()))
            response.result = Helpers.build_result(
                http_common_response.get_rsp())
        except EduKitException as e:
            logging.error(
                u"Call reportSignupPackage interface failed. ErrorMessage: %s",
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info('Call reportSignupPackage interface end')
        return response

    def batch_report_signup_course(self, user_id, user_id_type,
                                   batch_report_signup_course_request):
        """
        :param user_id:用户华为帐号ID
        :param user_id_type:user_id字段对应的帐号类型
        :param batch_report_signup_course_request:相关类
        :return: response
        """
        logging.info("Call reportSignupPackage interface start")
        response = Response()
        try:
            url = ApiConstant.BATCH_REPORT_SIGNUP_COURSE.format(
                user_id, user_id_type)
            http_common_response = \
                HttpCommonResponse(self.__request_sender.put(
                    url=url,
                    body=batch_report_signup_course_request.to_json_string()))
            response.result = Helpers.build_result(
                http_common_response.get_rsp())
        except EduKitException as e:
            logging.error(
                u"Call batchReportSignupCourse interface failed. "
                u"ErrorMessage: %s",
                str(e))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        logging.info("Call batchReportSignupCourse interface end")
        return response



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.image_file_info import ImageFileInfo


class CourseLocalizedData:
    def __init__(self):
        self._name = None
        self._short_description = None
        self._deeplink_url = None
        self._cover_image_file_info = None
        self._portrait_cover_image_file_info = None
        self._introduce_image_file_infos = None
        self._full_description = None

    @property
    def name(self):
        """
        :return: mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
         * 课程名称，说明如下：
         * 最大30字符（1个汉字也算1个字符）
         * 对于每种已添加的语言类型，课程提交前必须指定此字段。后续更新时可不携带此字段，此时将保留当前值不变
        :param name:
        :return:
        """
        self._name = name

    @property
    def short_description(self):
        """
        :return: mixed
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
         * 课程简要介绍，说明如下：
         * 最大40字符（1个汉字也算1个字符）
         * 对于每种已添加的语言类型，课程提交前必须指定此字段。后续更新时可不携带此字段，此时将保留当前值不变
        :param short_description:
        :return:
        """
        self._short_description = short_description

    @property
    def deeplink_url(self):
        """
        :return: mixed
        """
        return self._deeplink_url

    @deeplink_url.setter
    def deeplink_url(self, deeplink_url):
        """
         * 从教育中心App跳转到您的App的DeepLink链接，说明如下：
         * 如果用户需要跳转到您的App购买(eduappPurchased=false)或者学习
         (eduappUsed=false)此课程，在课程首次提交前必须提供此链接。
         如课程支持在教育中心直购和学习，则此字段为可选
         * 课程版本更新时可不携带此字段，此时将保留当前值不变
         * 从教育中心App通过此链接跳转到您的App后，您需要根据用户当前是否已购买此课程，确定展示购买页面还是学习页面
         * 可以在此链接中增加必要的参数以辅助跳转后在您的App内的逻辑处理，教育中心将透传这些参数。但请勿在链接中携带敏感数据（如用户密码等）
         * 提供此字段时，需要同时提供residentAGApp字段，以便能正确拉起您的App
        :param deeplink_url:
        :return:
        """
        self._deeplink_url = deeplink_url

    @property
    def cover_image_file_info(self):
        """
        :return: mixed
        """
        return self._cover_image_file_info

    @cover_image_file_info.setter
    def cover_image_file_info(self, cover_image_file_info: ImageFileInfo):
        # 横版封面图片文件信息
        self._cover_image_file_info = cover_image_file_info

    @property
    def portrait_cover_image_file_info(self):
        """
        :return: mixed
        """
        return self._portrait_cover_image_file_info

    @portrait_cover_image_file_info.setter
    def portrait_cover_image_file_info(
            self, portrait_cover_image_file_info: ImageFileInfo):
        """
        * 竖版封面图片文件信息
        * 课程类型为教辅教材时需要指定此字段
        :param portrait_cover_image_file_info:
        :return:
        """
        self._portrait_cover_image_file_info = portrait_cover_image_file_info

    @property
    def introduce_image_file_infos(self):
        """
        :return: mixed
        """
        return self._introduce_image_file_infos

    @introduce_image_file_infos.setter
    def introduce_image_file_infos(self,
                                   introduce_image_file_infos: ImageFileInfo):
        # 课程介绍图片文件信息列表
        self._introduce_image_file_infos = introduce_image_file_infos

    @property
    def full_description(self):
        """
        :return: mixed
        """
        return self._full_description

    @full_description.setter
    def full_description(self, full_description):
        """
         * 课程详细介绍，说明如下：
         * 最大2000字符（1个汉字也算1个字符）
         * 对于每种已添加的语言类型，课程提交前必须指定此字段。后续更新时可不携带此字段，此时将保留当前值不变
        :param full_description:
        :return:
        """
        self._full_description = full_description



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class UnitaryCourseLearningInfo:
    def __init__(self):
        self._start_time = None
        self._learning_status = None

    @property
    def start_time(self):
        """
        :return:mixed
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        设置本次学习开始时间。
        使用RFC3339定义的UTC时间格式(即GMT+00时区的时间)，例：2021-12-20T08:00:00Z。
        :param start_time:
        :return:
        """
        self._start_time = start_time

    @property
    def learning_status(self):
        """
        :return:mixed
        """
        return self._learning_status

    @learning_status.setter
    def learning_status(self, learning_status):
        """

        :param learning_status:
        :return:
        """
        self._learning_status = learning_status

    def to_json_string(self):
        """
        将对象转为JSON字符串
        :return:
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)),
                     encoding='utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.common.model.response import Response
from edukit_sdk.edukit.lesson.impl.lesson_handler import LessonHandler


class LessonDeleteRequest:
    def __init__(self, course_id, course_edit_id, lesson_id, credential_list):
        self._course_id = course_id
        self._course_edit_id = course_edit_id
        self._lesson_id = lesson_id
        self._lesson_handler = LessonHandler(
            EduKitRequestSender(credential_list))

    def delete_lesson(self):

        if self.check_parm_has_empty():
            rsp = Response()
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return rsp
        return self._lesson_handler.delete_lesson(self._course_id,
                                                  self._course_edit_id,
                                                  self._lesson_id)

    def reset_lesson(self):
        if self.check_parm_has_empty():
            rsp = Response()
            rsp.result = Helpers.build_error_result(
                CommonErrorCode.PARAM_CANNOT_BE_EMPTY)
            return rsp
        return self._lesson_handler.reset_lesson(self._course_id,
                                                 self._course_edit_id,
                                                 self._lesson_id)

    def check_parm_has_empty(self):
        if Helpers.has_empty_param(
                [self._course_id, self._course_edit_id, self._lesson_id]):
            logging.error(
                'CourseId or CourseEditId or LessonId can not be null '
                'when create lesson.'
            )
            return True
        else:
            return False



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from urllib import parse

from edukit_sdk.edukit.common.constant.http_constant import HttpConstant


class Request:
    def __init__(self,
                 url,
                 method,
                 headers,
                 body,
                 form_data=None,
                 params=None):
        if params and isinstance(params, dict):
            url += '?' + parse.urlencode(params)
        if not headers:
            headers = {
                HttpConstant.CONTENT_TYPE: HttpConstant.APPLICATION_JSON
            }

        self.url = url
        self.method = method
        if not headers:
            headers = dict()
        self.headers = headers
        if not body:
            body = dict()
        self.body = body
        if not form_data:
            form_data = dict()
        self.form_data = form_data



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.course.impl.course_handler import CourseHandler


class CourseStatusRequest:
    def __init__(self, course_id, credential_list):
        self._course_id = course_id
        self._credential_list = credential_list
        self._course_handler = CourseHandler(
            EduKitRequestSender(credential_list))

    def get_course_status(self):
        return self._course_handler.get_course_status(self._course_id)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.catalogue.impl.catalogue_handler import CatalogueHandler
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class CatalogueDeleteRequest:
    def __init__(self, course_id, course_edit_id, catalogue_id,
                 credential_list):
        self._course_id = course_id
        self._course_edit_id = course_edit_id
        self._catalogue_id = catalogue_id
        self._catalogue_handler = CatalogueHandler(
            EduKitRequestSender(credential_list))

    def delete(self):
        return self._catalogue_handler.delete_catalogue(
            self._course_id, self._course_edit_id, self._catalogue_id)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import os
import ssl
from urllib import request as request_kit

from edukit_sdk.edukit.common.config.config import Config
from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.http.client_response import ClientResponse


def ssl_certificate():
    # ssl验证
    ssl_path = os.path.join(CommonConstant.ROOT_PATH, CommonConstant.AUTH_DIR)
    certificate_path = os.path.join(CommonConstant.ROOT_PATH,
                                    CommonConstant.AUTH_DIR,
                                    CommonConstant.CERT)

    if not os.path.exists(certificate_path):
        if not os.path.exists(ssl_path):
            os.makedirs(ssl_path)
        cert = request_kit.urlopen(
            CommonConstant.DEFAULT_CERT_URL).read().decode(
                ClientConstant.UTF_8)
        with open(certificate_path,
                  CommonConstant.FILE_MODE_CREDENTIAL_WRITE,
                  encoding=ClientConstant.UTF_8) as fcertificate:
            os.chmod(certificate_path, CommonConstant.FILE_DEFAULT_MOD)
            fcertificate.write(cert)

    # 生成SSL上下文
    context = ssl.create_default_context()
    # 加载信任根证书
    context.load_verify_locations(certificate_path)
    return context


class Client:
    def __init__(self):
        config = Config()
        self._connectTimeout = config.get_config().get('CONNECT_TIMEOUT')
        self._operationTimeout = config.get_config().get('OPERATION_TIMEOUT')

    def send_request(self, request):
        """
        发送请求
        :param request: 请求内容
        :return:
        """
        data = request.body if request.body else None

        headers = request.headers

        # ssl验证
        ssl_context = ssl_certificate()

        # 发送请求
        request_box = request_kit.Request(url=request.url,
                                          data=data,
                                          headers=headers,
                                          method=request.method)
        # 请求异常捕获
        try:
            response = request_kit.urlopen(request_box,
                                           context=ssl_context,
                                           timeout=int(self._connectTimeout))
            body = str(response.read(), encoding=ClientConstant.UTF_8)
            rsp_code = response.status
            headers = response.headers
            return ClientResponse(rsp_code, headers, body, None)
        except Exception as e:
            raise EduKitException(str(e))



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.
from edukit_sdk.edukit.teacher.model.teacher import Teacher


class TeacherEdit:
    def __init__(self):
        self._teacher_edit_id = None
        self._teacher = None

    @property
    def teacher_edit_id(self):
        """
        mixed
        :return:
        """
        return self._teacher_edit_id

    @teacher_edit_id.setter
    def teacher_edit_id(self, teacher_edit_id):
        """
        教师编辑版本ID
        :param teacher_edit_id:
        :return:
        """
        self._teacher_edit_id = teacher_edit_id

    @property
    def teacher(self):
        """
        mixed
        :return:
        """
        return self._teacher

    @teacher.setter
    def teacher(self, teacher: Teacher):
        """
        教师SDK请求体模型，详见Teacher类
        :param teacher:
        :return:
        """
        self._teacher = teacher



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CreateLessonResult:
    def __init__(self):
        self._lesson_id = None
        self._lesson_edit_id = None
        self._result = None

    @property
    def lesson_edit_id(self):
        """
        :return:mixed
        """
        return self._lesson_edit_id

    @property
    def lesson_id(self):
        """
        :return:mixed
        """
        return self._lesson_id

    @lesson_edit_id.setter
    def lesson_edit_id(self, lesson_edit_id):
        """
        :param lesson_edit_id:
        """
        self._lesson_edit_id = lesson_edit_id

    @property
    def result(self):
        """
        :return:mixed
        """
        return self._result

    @lesson_id.setter
    def lesson_id(self, lesson_id):
        """
        :param lesson_id:
        """
        self._lesson_id = lesson_id

    @result.setter
    def result(self, result):
        """
        :param result:
        """
        self._result = result



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json
import logging
import os

from edukit_sdk.edukit.album.model.localized_data import LocalizedData
from edukit_sdk.edukit.album.resp.create_album_response import \
    CreateAlbumResponse
from edukit_sdk.edukit.album.resp.update_album_response import \
    UpdateAlbumResponse
from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse


class AlbumHandler:
    __img_type_list = {
        FileUploadConstant.RESOURCE_TYPE['COURSE_PACKAGE_HORIZONTAL_COVER']:
        'cover image',
        FileUploadConstant.RESOURCE_TYPE['ALBUM_LANDSCAPE_COVER']:
        'landscape cover image'
    }

    def __init__(self, request_sender):
        self.__request_sender = request_sender

    def create_album(self, album):
        logging.info('Call create_album interface start.')
        create_album_response = CreateAlbumResponse()
        try:
            url = ApiConstant.CREATE_ALBUM_URL
            body = album.to_json_string()
            response = HttpCommonResponse(
                self.__request_sender.post(url=url, body=body))
            create_album_response = Helpers.parse_response(
                response.get_rsp(),
                'edukit_sdk.edukit.album.resp.create_album_response'
                '.CreateAlbumResponse'
            )
        except EduKitException as e:
            logging.error('Call createAlbum interface failed.error_message:' +
                          str(e))
            create_album_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

        logging.info(
            'Call create_album interface end, and albumId: %s, albumEditId: %s'
            % (create_album_response.album_id, create_album_response.edit_id))

        return create_album_response

    def update_album(self, album_id, album):
        logging.info('Call update_album interface start.')
        update_album_response = UpdateAlbumResponse()
        try:
            url = ApiConstant.CREATE_UPDATE_ALBUM_URL.format(album_id)
            body = album.to_json_string()
            response = HttpCommonResponse(
                self.__request_sender.put(url=url, body=body))
            update_album_response = Helpers.parse_response(
                response.get_rsp(),
                'edukit_sdk.edukit.album.resp.update_album_response'
                '.UpdateAlbumResponse'
            )
        except EduKitException as e:
            logging.error('Call update_album interface failed.error_message:' +
                          str(e))
            update_album_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

        logging.info(
            'Call update_album interface end, and albumId: %s, albumEditId: %s'
            % (update_album_response.album_id, update_album_response.edit_id))

        return update_album_response

    def manage_album(self, album_id, action, removal_reason):
        logging.info('Call manage_album interface start.')
        try:
            url = ApiConstant.MANAGE_ALBUM_STATUS_URL.format(album_id)
            body = {"action": action, "removalReason": removal_reason}
            by = bytes(json.dumps(body), encoding='utf-8')
            response = HttpCommonResponse(
                self.__request_sender.post(url=url, body=by))
            logging.info('Call manage_album interface end. albumId: ' +
                         str(album_id))
            return Helpers.build_result(response.get_rsp())
        except EduKitException as e:
            logging.error(
                'Call manage_album interface failed. error_message: ' + str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

    def delete_album(self, album_id):
        logging.info('Call delete_album interface start.')
        try:
            url = ApiConstant.DELETE_ALBUM_URL.format(album_id)
            response = HttpCommonResponse(
                self.__request_sender.delete(url=url))
            logging.info('Call delete_album interface end. albumId: ' +
                         str(album_id))
            return Helpers.build_result(response.get_rsp())
        except EduKitException as e:
            logging.error(
                'Call delete_album interface failed. error_message:' + str(e))
            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

    def format_data(self, album):
        if not album.edit or not album.edit.localized_data:
            return album
        edit_localized_data_list = list()
        for item in album.edit.localized_data:
            edit_localized_data = LocalizedData()
            edit_localized_data.language = item.language
            edit_localized_data.name = item.name
            edit_localized_data.full_description = item.full_description

            if item.cover_img_file_info:
                upload_cover_img_result = self.upload_img(
                    item.cover_img_file_info)
                if not upload_cover_img_result:
                    return False
                if isinstance(upload_cover_img_result, str):
                    edit_localized_data.cover_img_id = upload_cover_img_result
            if item.landscape_cover_img_file_info:
                upload_landscape_img_result = self.upload_img(
                    item.landscape_cover_img_file_info)
                if not upload_landscape_img_result:
                    return False
                if isinstance(upload_landscape_img_result, str):
                    edit_localized_data.landscape_cover_img_id = \
                        upload_landscape_img_result

            edit_localized_data_list.append(edit_localized_data)

        album.edit.localized_data = edit_localized_data_list
        return album

    def upload_img(self, image_file_info):
        img_type = self.__img_type_list[image_file_info.resource_type]
        try:
            file_upload = FileUpload(
                path=image_file_info.path,
                resource_type=image_file_info.resource_type,
                request_sender=self.__request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error("Upload %s failed. errMsg:%s" % (img_type, str(e)))
            return FileUpload
        if not Helpers.is_success(result):
            logging.error("Upload %s failed. errMsg:%s" %
                          (img_type, result['result']['resultDesc']))

        return result['materialId']



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.helpers.helpers import Helpers


class CreateLessonEditRequest:
    def __init__(self):
        self._force_create_new_edit = None

    @property
    def force_create_new_edit(self):
        """
        :return:mixed
        """
        return self._force_create_new_edit

    @force_create_new_edit.setter
    def force_create_new_edit(self, force_create_new_edit):
        """
        :param force_create_new_edit:
        """
        self._force_create_new_edit = force_create_new_edit

    def to_bytes(self):
        """
        将对象转为JSON类型的字节
        :return:bytes
        """
        return bytes(json.dumps(Helpers.change_object_to_array(self)), 'utf-8')



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.course.model.change_course_status_data import \
    ChangeCourseStatusData
from edukit_sdk.edukit.course.model.course_meta_data import CourseMetaData


class Course:
    def __init__(self):
        self._course_id = None
        self._course_meta_data = None
        self._course_multi_language_data_list = None
        self._language_list_to_delete = None
        self._product_prices = None
        self._change_course_status_data = None
        self._progress_callback = None

    @property
    def course_id(self):
        """
        :return: mixed
        """
        return self._course_id

    @course_id.setter
    def course_id(self, course_id):
        """
        课程id
        :param course_id:
        :return:
        """
        self._course_id = course_id

    @property
    def course_meta_data(self):
        """
        :return: mixed
        """
        return self._course_meta_data

    @course_meta_data.setter
    def course_meta_data(self, course_meta_data: CourseMetaData):
        """
        课程元数据
        :param course_meta_data:
        :return:
        """
        self._course_meta_data = course_meta_data

    @property
    def course_multi_language_data_list(self):
        """
        :return: mixed
        """
        return self._course_multi_language_data_list

    @course_multi_language_data_list.setter
    def course_multi_language_data_list(self, course_multi_language_data_list):
        """
         课程本地化多语言数据列表
        :param course_multi_language_data_list:
        :return:
        """
        self._course_multi_language_data_list = course_multi_language_data_list

    @property
    def language_list_to_delete(self):
        """
        :return:mixed
        """
        return self._language_list_to_delete

    @language_list_to_delete.setter
    def language_list_to_delete(self, language_list_to_delete):
        """
        待删除的本地化多语言数据语言列表
        :param language_list_to_delete:
        :return:
        """
        self._language_list_to_delete = language_list_to_delete

    @property
    def product_prices(self):
        """
        :return: mixed
        """
        return self._product_prices

    @product_prices.setter
    def product_prices(self, product_prices):
        """
        课程定价列表
        :param product_prices:
        :return:
        """
        self._product_prices = product_prices

    @property
    def change_course_status_data(self):
        """
        :return: mixed
        """
        return self._change_course_status_data

    @change_course_status_data.setter
    def change_course_status_data(
            self, change_course_status_data: ChangeCourseStatusData):
        """
        changeCourseStatus请求消息体
        :param change_course_status_data:
        :return:
        """
        self._change_course_status_data = change_course_status_data

    @property
    def progress_callback(self):
        """
        :return: mixed
        """
        return self._progress_callback

    @progress_callback.setter
    def progress_callback(self, progress_callback):
        """
        文件上传进度回调函数
        :param progress_callback:
        :return:
        """
        self._progress_callback = progress_callback



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class TeacherCreateResult:
    def __init__(self):
        self._edit_id = None
        self._teacher_id = None
        self._result = None

    @property
    def edit_id(self):
        return self._edit_id

    @edit_id.setter
    def edit_id(self, edit_id):
        self._edit_id = edit_id

    @property
    def teacher_id(self):
        return self._teacher_id

    @teacher_id.setter
    def teacher_id(self, teacher_id):
        self._teacher_id = teacher_id

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, result):
        self._result = result



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.course.impl.course_handler import CourseHandler
from edukit_sdk.edukit.course.model.course import Course


class CourseOffShelfRequest:
    def __init__(self, course: Course, credential_list):
        self._course = course
        self._course_handler = CourseHandler(
            EduKitRequestSender(credential_list))

    def off_shelf(self):
        return self._course_handler.off_shelf(self._course)



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class TeacherUpdateResponse(Response):
    def __init__(self):
        super(TeacherUpdateResponse, self).__init__()
        self._teacher_edit_id = None
        self._teacher_id = None
        self._create_new_edit_result = None
        self._update_basic_info_result = None
        self._update_metadata_result = None
        self._update_localized_data_result = None
        self._delete_localized_data_result = None
        self._teacher_commit_result = None

    @property
    def teacher_edit_id(self):
        return self._teacher_edit_id

    @teacher_edit_id.setter
    def teacher_edit_id(self, teacher_edit_id):
        self._teacher_edit_id = teacher_edit_id

    @property
    def teacher_id(self):
        return self._teacher_id

    @teacher_id.setter
    def teacher_id(self, teacher_id):
        self._teacher_id = teacher_id

    @property
    def create_new_edit_result(self):
        return self._create_new_edit_result

    @create_new_edit_result.setter
    def create_new_edit_result(self, create_new_edit_result):
        self._create_new_edit_result = create_new_edit_result

    @property
    def update_basic_info_result(self):
        return self._update_basic_info_result

    @update_basic_info_result.setter
    def update_basic_info_result(self, update_basic_info_result):
        self._update_basic_info_result = update_basic_info_result

    @property
    def update_metadata_result(self):
        return self._update_metadata_result

    @update_metadata_result.setter
    def update_metadata_result(self, update_metadata_result):
        self._update_metadata_result = update_metadata_result

    @property
    def update_localized_data_result(self):
        return self._update_localized_data_result

    @update_localized_data_result.setter
    def update_localized_data_result(self, update_localized_data_result):
        self._update_localized_data_result = update_localized_data_result

    @property
    def delete_localized_data_result(self):
        return self._delete_localized_data_result

    @delete_localized_data_result.setter
    def delete_localized_data_result(self, delete_localized_data_result):
        self._delete_localized_data_result = delete_localized_data_result

    @property
    def teacher_commit_result(self):
        return self._teacher_commit_result

    @teacher_commit_result.setter
    def teacher_commit_result(self, teacher_commit_result):
        self._teacher_commit_result = teacher_commit_result



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CourseMultiLanguageData:
    def __init__(self):
        self._language = None
        self._course_localized_data = None
        self._media_localized_data_list = None

    @property
    def language(self):
        """
        :return: mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        多语言信息
        :param language:
        :return:
        """
        self._language = language

    @property
    def course_localized_data(self):
        """
        :return: mixed
        """
        return self._course_localized_data

    @course_localized_data.setter
    def course_localized_data(self, course_localized_data):
        """
        课程本地化多语言数据对象
        :param course_localized_data:
        :return:
        """
        self._course_localized_data = course_localized_data

    @property
    def media_localized_data_list(self):
        """
        :return: mixed
        """
        return self._media_localized_data_list

    @media_localized_data_list.setter
    def media_localized_data_list(self, media_localized_data_list):
        """
        媒体文件列表
        :param media_localized_data_list:
        :return:
        """
        self._media_localized_data_list = media_localized_data_list



# -*- coding: utf-8 -*-
# Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class AlbumLocalizeData:
    def __init__(self):
        self._language = None
        self._name = None
        self._full_description = None
        self._cover_img_file_info = None
        self._landscape_cover_img_file_info = None

    @property
    def full_description(self):
        """
        :return:mixed
        """
        return self._full_description

    @full_description.setter
    def full_description(self, full_description):
        """
        专辑详细介绍。最大2000字符
        :param full_description:
        :return:
        """
        self._full_description = full_description


    @property
    def cover_img_file_info(self):
        """
        :return: mixed
        """
        return self._cover_img_file_info

    @cover_img_file_info.setter
    def cover_img_file_info(self, cover_img_file_info):
        """
        专辑封面图素材信息
        :param cover_img_file_info:
        :return:
        """
        self._cover_img_file_info = cover_img_file_info

    @property
    def language(self):
        """
        :return:mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        语言代码，由BCP-47定义，如简体中文为"zh-cn"
        :param language:
        :return:
        """
        self._language = language

    @property
    def landscape_cover_img_file_info(self):
        """
        :return:mixed
        """
        return self._landscape_cover_img_file_info

    @landscape_cover_img_file_info.setter
    def landscape_cover_img_file_info(self, landscape_cover_img_file_info):
        """
        专辑横版封面图素材信息
        :param landscape_cover_img_file_info:
        :return:
        """
        self._landscape_cover_img_file_info = landscape_cover_img_file_info

    @property
    def name(self):
        """
        :return:mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        专辑名称。最大15字符
        :param name:
        :return:
        """
        self._name = name


# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

from edukit_sdk.edukit.common.model.response import Response


class CreateCatalogueResponse(Response):
    def __init__(self):
        self._catalogue_id = None
        self._catalogue_edit_id = None
        super(CreateCatalogueResponse, self).__init__()

    @property
    def catalogue_id(self):
        return self._catalogue_id

    @catalogue_id.setter
    def catalogue_id(self, catalogue_id):
        self._catalogue_id = catalogue_id

    @property
    def catalogue_edit_id(self):
        return self._catalogue_edit_id

    @catalogue_edit_id.setter
    def catalogue_edit_id(self, catalogue_edit_id):
        self._catalogue_edit_id = catalogue_edit_id



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import json

from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException


class ClientResponse:
    def __init__(self, code, headers=None, body=None, error=None):
        self.statusCode = code
        self.headers = headers
        self.body = body
        self.error = error
        self.rsp_data = None

        if error:
            return

        if not body:
            if code >= 400:
                raise EduKitException('http request status code is %s' % code)
        else:
            self.rsp_data = json.loads(body)
        if code >= 400:
            self.error = self.rsp_data

    def get_error(self):
        return self.error

    def get_headers(self):
        return self.headers

    def get_rsp(self):
        return self.rsp_data



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class LessonEdit:
    def __init__(self):
        self._course_id = None
        self._course_edit_id = None
        self._lesson_edit_id = None
        self._lesson = None

    @property
    def course_id(self):
        """
        :return:mixed
        """
        return self._course_id

    @course_id.setter
    def course_id(self, course_id):
        """
        设置课程ID。创建课程时返回，通过getCourseId()获取。
        :param course_id:
        """
        self._course_id = course_id

    @property
    def course_edit_id(self):
        """
        :return:mixed
        """
        return self._course_edit_id

    @course_edit_id.setter
    def course_edit_id(self, course_edit_id):
        """
        设置课程版本ID。创建或更新课程时返回，也可用通过createNewEdit()创建新的课程编辑版本。
        :param course_edit_id:
        """
        self._course_edit_id = course_edit_id

    @property
    def lesson_edit_id(self):
        """
        :return:mixed
        """
        return self._lesson_edit_id

    @lesson_edit_id.setter
    def lesson_edit_id(self, lesson_edit_id):
        """
        设置章节版本ID，用于标识课程章节的一个版本，每次对章节进行更新时都需要生成一个新的版本ID。
        章节版本ID通过createLesson接口(首次创建章节时)或updateLesson接口(后续更新章节时)获得。
        :param lesson_edit_id:
        """
        self._lesson_edit_id = lesson_edit_id

    @property
    def lesson(self):
        """
        :return:mixed
        """
        return self._lesson

    @lesson.setter
    def lesson(self, lesson):
        """
        设置章节数据。
        :param lesson:
        """
        self._lesson = lesson



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging

from edukit_sdk.edukit.common.errorcode.common_error_code import \
    CommonErrorCode
from edukit_sdk.edukit.common.constant.api_constant import ApiConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.constant.common_constant import CommonConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
from edukit_sdk.edukit.common.http.http_common_response import \
    HttpCommonResponse
from edukit_sdk.edukit.common.model.media_localized_data import \
    MediaLocalizedData
from edukit_sdk.edukit.common.model.response import Response
from edukit_sdk.edukit.common.helpers.helpers import Helpers
from edukit_sdk.edukit.common.model.update_media_localized_data import \
    UpdateMediaLocalizedData
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender
from edukit_sdk.edukit.course.constant.course_constant import CourseConstant
from edukit_sdk.edukit.course.impl.change_course_status_request import \
    ChangeCourseStatusRequest
from edukit_sdk.edukit.course.impl.create_course_result import \
    CreateCourseResult
from edukit_sdk.edukit.course.impl.update_edit_localized_data import \
    UpdateEditLocalizedData
from edukit_sdk.edukit.course.impl.update_localized_data_request import \
    UpdateLocalizedDataRequest
from edukit_sdk.edukit.course.impl.update_product_price_request import \
    UpdateProductPriceRequest
from edukit_sdk.edukit.course.model.course import Course
from edukit_sdk.edukit.course.model.course_edit import CourseEdit
from edukit_sdk.edukit.course.model.course_localized_data import \
    CourseLocalizedData
from edukit_sdk.edukit.course.model.course_meta_data import CourseMetaData
from edukit_sdk.edukit.course.resp.course_status_response import \
    CourseStatusResponse
from edukit_sdk.edukit.course.resp.course_update_response import \
    CourseUpdateResponse


class CourseHandler:
    def __init__(self, request_sender: EduKitRequestSender):
        self._request_sender = request_sender

    def create_course(self):
        logging.info('Call Course createCourse interface start.')
        create_course_result = CreateCourseResult()
        try:
            url = ApiConstant.CREATE_COURSE_URL
            response = HttpCommonResponse(self._request_sender.post(url=url))
            create_course_result = Helpers.parse_response(
                response.get_rsp(), CourseConstant.CREATE_COURSE_RESULT)
        except EduKitException as e:
            logging.error(
                'Call course createCourse interface failed.error_message: %s' %
                e.message)
            create_course_result.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
        logging.info(
            'Call course createCourse interface end,and course_id: '
            '%s, edit_id: %s'
            % (create_course_result.course_id, create_course_result.edit_id))

        return create_course_result

    def update_course(self, course: Course,
                      create_course_result: CreateCourseResult):
        if course.course_meta_data:
            update_meta_data_result = self._update_meta_data(
                course.course_meta_data, create_course_result)
            if not update_meta_data_result:
                return False

        if course.course_multi_language_data_list:
            update_multi_language_data_list_result = \
                self._update_multi_language_data_list(
                    course, create_course_result)
            if not update_multi_language_data_list_result:
                return False

        if course.product_prices:
            update_product_prices_result = self._update_product_price(
                course.product_prices, create_course_result.course_id)
            if not update_product_prices_result:
                return False

        return True

    def update_course_edit(self, course_edit: CourseEdit,
                           create_course_result: CreateCourseResult):
        if not course_edit.course:
            return True

        if course_edit.course.course_meta_data:
            update_meta_data_result = self._update_meta_data(
                course_edit.course.course_meta_data, create_course_result)
            if not update_meta_data_result:
                return False

        if course_edit.course.course_multi_language_data_list:
            update_multi_language_data_list_result = \
                self._update_multi_language_data_list(
                    course_edit.course, create_course_result)
            if not update_multi_language_data_list_result:
                return False

        if course_edit.course.language_list_to_delete:
            del_course_localized_data_result = self._del_course_localized_data(
                course_edit.course, create_course_result)
            if not del_course_localized_data_result:
                return False

        if course_edit.course.product_prices:
            update_product_prices_result = self._update_product_price(
                course_edit.course.product_prices,
                create_course_result.course_id)
            if not update_product_prices_result:
                return False

        return True

    def _update_meta_data(self, course_meta_data: CourseMetaData,
                          create_course_result: CreateCourseResult):
        logging.info(
            'Call course updateMetaData interface start and '
            'course_id:%s, edit_id:%s'
            % (create_course_result.course_id, create_course_result.edit_id))
        try:
            url = ApiConstant.UPDATE_META_COURSE_URL.format(
                create_course_result.course_id, create_course_result.edit_id)
            update_meta_data_response = HttpCommonResponse(
                self._request_sender.put(url=url,
                                         body=course_meta_data.to_bytes()))
        except EduKitException as e:
            logging.error(
                'Call course updateMetaData interface failed and '
                'course_id:%s, edit_id:%s, error_message:%s'
                % (create_course_result.course_id,
                   create_course_result.edit_id, e.message))
            return False

        if not Helpers.is_success(update_meta_data_response.get_rsp()):
            result = update_meta_data_response.get_rsp()
            logging.error(
                'Call course updateMetaData interface failed and '
                'course_id:%s,edit_id:%s,error_message:%s,resultCode:'
                '%s' %
                (create_course_result.course_id, create_course_result.edit_id,
                 result.get(CourseConstant.RESULT).get(
                     CourseConstant.RESULT_DESC),
                 result.get(CourseConstant.RESULT).get(
                     CourseConstant.RESULT_CODE)))
            return False

        logging.info('Call course updateMetaData interface end')
        return True

    def _update_multi_language_data_list(
            self, course: Course, create_course_result: CreateCourseResult):
        # 包含课程章节 课程视频文件、课程音频文件,给出warnning
        self._course_media_type_warning(course)

        logging.info(
            'Call course updateLocalizedData interface start when updating '
            'course localizedData and course_id:%s, edit_'
            'id:%s' %
            (create_course_result.course_id, create_course_result.edit_id))
        update_flag = True
        for course_multi_language_data in \
                course.course_multi_language_data_list:
            update_localized_data_request = UpdateLocalizedDataRequest()
            if course_multi_language_data and \
                    course_multi_language_data.course_localized_data:
                localized_data_result = self._upload_localized_data(
                    course_multi_language_data.course_localized_data)
                if not localized_data_result:
                    return False
                update_localized_data_request.localized_data = \
                    localized_data_result

            if course_multi_language_data and \
                    course_multi_language_data.media_localized_data_list:
                upload_media_data_result_list = list()
                update_flag = True
                for media_localized_data in \
                        course_multi_language_data.media_localized_data_list:
                    single_result = self.upload_media_localized_data(
                        media_localized_data)
                    if not single_result:
                        update_flag = False
                        break
                    upload_media_data_result_list.append(single_result)

                if update_flag:
                    update_localized_data_request.localized_media = \
                        upload_media_data_result_list

            try:
                url = ApiConstant.UPDATE_LOCALIZED_COURSE_URL.format(
                    create_course_result.course_id,
                    create_course_result.edit_id,
                    course_multi_language_data.language)
                response = HttpCommonResponse(
                    self._request_sender.put(
                        url=url,
                        body=update_localized_data_request.to_bytes()))
                if not Helpers.is_success(response.get_rsp()):
                    result = response.get_rsp()
                    logging.error(
                        'Call course updateLocalizedData interface failed '
                        'and course_id:%s, edit_id:%s, error_message:'
                        ' %s, resultCode: %s' %
                        (create_course_result.course_id,
                         create_course_result.edit_id,
                         result.get(CourseConstant.RESULT).get(
                             CourseConstant.RESULT_DESC),
                         result.get(CourseConstant.RESULT).get(
                             CourseConstant.RESULT_CODE)))
                    update_flag = False
                    break
            except EduKitException as e:
                logging.error(
                    'Call course updateLocalizedData interface failed and '
                    'course_id:%s, edit_id:%s, error_message: %s'
                    % (create_course_result.course_id,
                       create_course_result.edit_id, e.message))
                update_flag = False
                break

        logging.info(
            'Call course updateLocalizedData interface end and '
            'course_id:%s, edit_id:%s'
            % (create_course_result.course_id, create_course_result.edit_id))
        return update_flag

    def _del_course_localized_data(self, course: Course,
                                   create_course_result: CreateCourseResult):
        del_flag = True
        for language in course.language_list_to_delete:
            logging.info(
                'Call course deleteLocalizedData interface start and '
                'course_id:%s,edit_id:%s,language:%s'
                % (create_course_result.course_id,
                   create_course_result.edit_id, language))
            try:
                url = ApiConstant.DELETE_COURSE_URL.format(
                    create_course_result.course_id,
                    create_course_result.edit_id, language)
                response = HttpCommonResponse(
                    self._request_sender.delete(url=url))
                if not Helpers.is_success(response.get_rsp()):
                    result = response.get_rsp()
                    logging.error(
                        'Call course deleteLocalizedData interface failed and '
                        'course_id:%s, edit_id:%s, language:%s, '
                        'errormessage: %s, errorCode: %s' %
                        (create_course_result.course_id,
                         create_course_result.edit_id, language,
                         result.get(CourseConstant.RESULT).get(
                             CourseConstant.RESULT_DESC),
                         result.get(CourseConstant.RESULT).get(
                             CourseConstant.RESULT_CODE)))
                    del_flag = False
                    break
            except EduKitException as e:
                logging.error(
                    'Call course deleteLocalizedData interface failed and '
                    'course_id:%s, edit_id:%s, language:%s, error'
                    'message:%s, errorCode:%s' %
                    (create_course_result.course_id,
                     create_course_result.edit_id, language, e.message,
                     e.code))
                del_flag = False
                break
            logging.info(
                'Call course deleteLocalizedData interface end and '
                'course_id:%s,edit_id:%s,language:%s'
                % (create_course_result.course_id,
                   create_course_result.edit_id, language))

        return del_flag

    def _course_media_type_warning(self, course: Course):
        if not course.course_meta_data:
            return
        if not course.course_meta_data.meta_data:
            return
        if not course.course_meta_data.meta_data.include_lessons:
            return

        multi_language_data_list = course.course_multi_language_data_list
        for multi_language_data in multi_language_data_list:
            if multi_language_data.media_localized_data_list:
                for media_localized_data in \
                        multi_language_data.media_localized_data_list:
                    if self._is_audio_or_video_file(media_localized_data):
                        logging.warning(
                            'Course video or audio(mediaType is 2 or 3) is '
                            'not needed when the course includes lessons.')
                        break

    @staticmethod
    def _is_audio_or_video_file(media_localized_data: MediaLocalizedData):
        return media_localized_data.media_type in (
            CommonConstant.MEDIA_TYPE.get(CourseConstant.COURSE_AUDIO_FILE),
            CommonConstant.MEDIA_TYPE.get(CourseConstant.COURSE_VIDEO_FILE))

    def _upload_localized_data(self,
                               course_localized_data: CourseLocalizedData):
        edit_localized_data = UpdateEditLocalizedData()
        edit_localized_data.name = course_localized_data.name
        edit_localized_data.short_description = \
            course_localized_data.short_description
        edit_localized_data.full_description = \
            course_localized_data.full_description
        edit_localized_data.deeplink_url = course_localized_data.deeplink_url
        if course_localized_data:
            upload_cover_img_result = self._upload_cover_image(
                course_localized_data)
            if not upload_cover_img_result:
                return False

            if isinstance(upload_cover_img_result, str):
                edit_localized_data.cover_id = upload_cover_img_result

            upload_portrait_img_result = self._upload_portrait_image(
                course_localized_data)
            if not upload_portrait_img_result:
                return False
            if isinstance(upload_portrait_img_result, str):
                edit_localized_data.portrait_cover_id = \
                    upload_portrait_img_result

            upload_introduce_img_result = self._upload_introduce_image(
                course_localized_data)
            if not isinstance(upload_introduce_img_result,
                              dict) and not upload_introduce_img_result:
                logging.error('Upload introduceImage failed.')
                return False

            if isinstance(upload_introduce_img_result, list):
                edit_localized_data.introduce_ids = upload_introduce_img_result

        return edit_localized_data

    def off_shelf(self, course: Course):
        if not course or not course.course_id:
            logging.error('CourseId can not be empty when offShelf course.')
            return Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
        course_id = course.course_id
        logging.info('OffShelf course start and course_id: %s' % course_id)
        response = Response()
        try:
            url = ApiConstant.REMOVE_COURSE_URL.format(course_id)
            body = None
            if course.change_course_status_data:
                body = course.change_course_status_data.to_bytes()
            http_common_response = HttpCommonResponse(
                self._request_sender.put(url=url, body=body))
        except EduKitException as e:
            logging.error(
                'Call offShelf course interface failed and '
                'course_id:%s,error_message:%s'
                % (course_id, e.message))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response
        if not Helpers.is_success(http_common_response.get_rsp()):
            result = http_common_response.get_rsp()
            logging.error(
                'Call offShelf course interface failed.course_id:%s,'
                'error_message:%s'
                % (course_id, result.get(CourseConstant.RESULT).get(
                    CourseConstant.RESULT_DESC)))
            response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return response

        logging.info(
            'OffShelf course end and result: %s' %
            Helpers.build_result(http_common_response.get_rsp()).to_string())
        response.result = Helpers.build_result(http_common_response.get_rsp())
        return response

    def get_course_status(self, course_id):
        if not course_id:
            logging.error('CourseId can not be empty')
            return Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
        logging.info(
            'Call course getCourseStatus interface start,and course_id: %s' %
            course_id)
        course_status_response = CourseStatusResponse()
        try:
            url = ApiConstant.GET_COURSE_STATUS_URL.format(course_id)
            response = HttpCommonResponse(self._request_sender.get(url=url))
            if response.get_rsp() and response.get_rsp().get(
                    'result') and response.get_rsp().get('result').get(
                        'resultCode') != CommonConstant.RESULT_SUCCESS:
                result = response.get_rsp()
                logging.error(
                    'Call course getCourseStatus interface failed.'
                    'course_id:%s,error_message:%s' %
                    (course_id, result.get(
                        CourseConstant.RESULT).get(
                        CourseConstant.RESULT_DESC)))
                course_status_response.result = Helpers.build_error_result(
                    CommonErrorCode.CALL_API_INTERFACE_FAILED)
                return course_status_response
            course_status_response = Helpers.parse_response(
                response.get_rsp(), CourseConstant.COURSE_STATUS_RESPONSE)
        except EduKitException as e:
            logging.error(
                'Call course getCourseStatus interface failed and '
                'course_id:%s, errorMsg:%s.'
                % (course_id, e.message))
            course_status_response.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return course_status_response

        logging.info('Call course getCourseStatus interface end')
        course_status_response.result = Helpers.build_error_result(
            CommonErrorCode.SUCCESS)
        return course_status_response

    def upload_media_localized_data(self,
                                    media_localized_data: MediaLocalizedData):
        update_media_localized_data = UpdateMediaLocalizedData()
        update_media_localized_data.media_type = \
            media_localized_data.media_type
        update_media_localized_data.height = media_localized_data.height
        update_media_localized_data.width = media_localized_data.width
        update_media_localized_data.media_len = media_localized_data.media_len
        update_media_localized_data.ordinal = media_localized_data.ordinal

        upload_frame_img_result = self._upload_frame_image(
            media_localized_data)
        if not upload_frame_img_result:
            return False
        if isinstance(upload_frame_img_result, str):
            update_media_localized_data.frame_id = upload_frame_img_result

        upload_media_result = self._upload_media(media_localized_data)
        if not upload_media_result:
            return False
        if isinstance(upload_media_result, dict):
            update_media_localized_data.meida_id = upload_media_result.get(
                CourseConstant.MATERIAL_Id)
            update_media_localized_data.file_name = Helpers.get_file_base_name(
                upload_media_result.get(CourseConstant.PATH))
            update_media_localized_data.size = Helpers.get_file_size(
                upload_media_result.get(CourseConstant.PATH))
            update_media_localized_data.sha256 = Helpers.get_sha256(
                upload_media_result.get(CourseConstant.PATH))

        return update_media_localized_data

    def _upload_cover_image(self, course_localized_data: CourseLocalizedData):
        if not course_localized_data.cover_image_file_info:
            return True
        try:
            file_upload = FileUpload(
                path=course_localized_data.cover_image_file_info.path,
                resource_type=FileUploadConstant.RESOURCE_TYPE[
                    CourseConstant.COURSE_PACKAGE_HORIZONTAL_COVER],
                request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload horizon cover image failed. errMsg:%s' %
                          e.message)
            return False

        if not Helpers.is_success(result):
            logging.error('Upload horizon cover image failed. errMsg:%s' %
                          result.get(CourseConstant.RESULT).get(
                              CourseConstant.RESULT_DESC))
            return False

        return result.get('materialId')

    def _upload_portrait_image(self,
                               course_localized_data: CourseLocalizedData):
        if not course_localized_data.portrait_cover_image_file_info:
            return True

        try:
            file_upload = FileUpload(
                path=course_localized_data.portrait_cover_image_file_info.path,
                resource_type=FileUploadConstant.RESOURCE_TYPE[
                    CourseConstant.COURSE_PORTRAIT_COVER],
                request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload portrait image failed. errMsg:%s' %
                          e.message)
            return False

        if not Helpers.is_success(result):
            logging.error('Upload portrait image failed. errMsg:%s' %
                          result.get(CourseConstant.RESULT).get(
                              CourseConstant.RESULT_DESC))
            return False

        return result.get(CourseConstant.MATERIAL_Id)

    def _upload_introduce_image(self,
                                course_localized_data: CourseLocalizedData):
        if not course_localized_data.introduce_image_file_infos:
            return True

        material_id_list = list()
        for introduce_image_file_info in \
                course_localized_data.introduce_image_file_infos:
            try:
                file_upload = FileUpload(
                    path=introduce_image_file_info.path,
                    resource_type=FileUploadConstant.RESOURCE_TYPE[
                        CourseConstant.COURSE_PACKAGE_INTRODUCTION],
                    request_sender=self._request_sender)
                result = file_upload.upload()
            except EduKitException:
                return False

            if not Helpers.is_success(result):
                logging.error('Upload introduce image failed. errMsg:%s' %
                              result.get(CourseConstant.RESULT).get(
                                  CourseConstant.RESULT_DESC))
                return False

            material_id_list.append(result.get(CourseConstant.MATERIAL_Id))

        return material_id_list

    def _upload_frame_image(self, media_localized_data: MediaLocalizedData):
        if not media_localized_data.frame_image_file_info:
            return True

        try:
            file_upload = FileUpload(
                path=media_localized_data.frame_image_file_info.path,
                resource_type=FileUploadConstant.RESOURCE_TYPE[
                    CourseConstant.PROMOTIONAL_VIDEO_POSTER],
                request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload frame image failed. errMsg: %s' % e.message)
            return False

        if not Helpers.is_success(result):
            logging.error('Upload frame image failed. errMsg: %s' % result.get(
                CourseConstant.RESULT).get(CourseConstant.RESULT_DESC))
            return False

        return result.get(CourseConstant.MATERIAL_Id)

    def _upload_media(self, media_localized_data: MediaLocalizedData):
        if not media_localized_data.media_file_info:
            return True
        public_file = False
        if media_localized_data.media_type is CommonConstant.MEDIA_TYPE.get(
                CourseConstant.COURSE_INTRODUCTION_VIDEO):
            public_file = True

        try:
            file_upload = FileUpload(
                path=media_localized_data.media_file_info.path,
                file_type=media_localized_data.media_file_info.file_type,
                public_file=public_file,
                request_sender=self._request_sender)
            result = file_upload.upload()
        except EduKitException as e:
            logging.error('Upload media failed. errMsg: %s' % e.message)
            return False

        if not Helpers.is_success(result):
            logging.error('Upload media failed. errMsg: %s' % result.get(
                CourseConstant.RESULT).get(CourseConstant.RESULT_DESC))
            return False

        return {
            CourseConstant.PATH: media_localized_data.media_file_info.path,
            CourseConstant.MATERIAL_Id: result.get(CourseConstant.MATERIAL_Id)
        }

    def _update_product_price(self, produce_prices, course_id):
        logging.info(
            'Call course updateProductPrice interface start and course_id:%s' %
            course_id)
        try:
            update_product_price_request = UpdateProductPriceRequest()
            update_product_price_request.product_prices = produce_prices
            url = ApiConstant.UPDATE_PRICE_COURSE_URL.format(course_id)
            response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=update_product_price_request.to_bytes()))
        except EduKitException as e:
            logging.error(
                'Call course updateProductPrice interface failed and '
                'course_id:%s, error_message:%s'
                % (course_id, e.message))
            return False

        if not Helpers.is_success(response.get_rsp()):
            result = response.get_rsp()
            logging.error(
                'Call course updateProductPrice interface failed and '
                'course_id:%s, error_message:%s, resultCode:%s'
                % (course_id, result.get(CourseConstant.RESULT).get(
                    CourseConstant.RESULT_DESC),
                   result.get(CourseConstant.RESULT).get(
                       CourseConstant.RESULT_CODE)))
            return False

        logging.info('Call course updateProductPrice interface end')
        return True

    def commit_course(self, course_id, edit_id, course: Course,
                      change_course_status_request: ChangeCourseStatusRequest):
        logging.info(
            'Call course commit_course interface start and course_id:%s, '
            'edit_id:%s'
            % (course_id, edit_id))
        try:
            if course.change_course_status_data and \
                    course.change_course_status_data.remarks:
                change_course_status_request.remarks = \
                    course.change_course_status_data.remarks
            if course.change_course_status_data and \
                    course.change_course_status_data.removal_reason:
                change_course_status_request.removal_reason = \
                    course.change_course_status_data.removal_reason
            url = ApiConstant.COMMIT_COURSE_URL.format(course_id, edit_id)
            response = HttpCommonResponse(
                self._request_sender.put(
                    url=url, body=change_course_status_request.to_bytes()))
        except EduKitException as e:
            logging.error(
                'Call course commit_course interface failed and course_id:%s, '
                'edit_id:%s, error_message: %s'
                % (course_id, edit_id, e.message))

            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

        if not Helpers.is_success(response.get_rsp()):
            result = response.get_rsp()
            logging.error(
                'Call course commit_course interface failed and course_id:%s, '
                'edit_id:%s, error_message: %s, result_'
                'code'
                ': %s' % (course_id, edit_id, result.get(
                    CourseConstant.RESULT).get(CourseConstant.RESULT_DESC),
                    result.get(CourseConstant.RESULT).get(
                    CourseConstant.RESULT_CODE)))

            return Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)

        logging.info('Call course commit_course interface end.')
        return Helpers.build_error_result(CommonErrorCode.SUCCESS)

    def create_new_course_edit(self, course_edit: CourseEdit):
        course_id = None
        if course_edit.course and course_edit.course.course_id:
            course_id = course_edit.course.course_id
        update_course = CourseUpdateResponse()
        if not course_id:
            logging.error(
                'CourseId can not be null when create a new course edition.')
            update_course.result = Helpers.build_error_result(
                CommonErrorCode.INVALID_COURSE_PARAMS)
            return update_course
        try:
            logging.info(
                'Call createCourseEdit interface start and course_id:%s' %
                course_id)
            url = ApiConstant.CREATE_NEW_COURSE_EDIT_URL.format(course_id)
            response = HttpCommonResponse(self._request_sender.post(url=url))
            create_course_result = Helpers.parse_response(
                response.get_rsp(), CourseConstant.CREATE_COURSE_RESULT)
            update_course.course_id = course_id
            update_course.edit_id = create_course_result.edit_id
            update_course.result = create_course_result.result
            logging.info(
                'Call createCourseEdit interface end and resultCode:%s,:'
                'error_message%s'
                % (create_course_result.result.result_desc,
                   create_course_result.result.result_code))

            return update_course
        except EduKitException as e:
            logging.error(
                'Call createCourseEdit interface failed and course_id:%s, '
                'error_message:%s, resultCode:%s'
                % (course_id, e.message, e.code))
            update_course.result = Helpers.build_error_result(
                CommonErrorCode.CALL_API_INTERFACE_FAILED)
            return update_course



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.

import logging
import os
import re

from edukit_sdk.edukit.common.constant.client_constant import ClientConstant
from edukit_sdk.edukit.common.constant.error_constant import ErrorConstant
from edukit_sdk.edukit.common.constant.file_upload_constant import \
    FileUploadConstant
from edukit_sdk.edukit.common.exception.edu_kit_exception import \
    EduKitException
from edukit_sdk.edukit.common.file_upload.file_upload_request import \
    FileUploadRequest
from edukit_sdk.edukit.common.file_upload.file_uploader_factory import \
    FileUploaderFactory
from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
    EduKitRequestSender


class FileUpload:
    def __init__(
        self,
        path,
        request_sender: EduKitRequestSender,
        resource_type=None,
        file_type=None,
        public_file=False,
    ):
        """
        文件上传
        :param path: 上传的文件路径
        :param request_sender: 封装请求信息
        :param resource_type: 资源文件类型
        :param file_type: 媒体文件类型
        :param public_file:
        """
        self._file_request = FileUploadRequest(path=path,
                                               file_type=file_type,
                                               resource_type=resource_type,
                                               public_file=public_file)
        self._relative_path_pattern = FileUploadConstant.RELATIVE_PATH_PATTERN
        self._resource_type_dict = FileUploadConstant.RESOURCE_TYPE
        self.__get_init_object(path, file_type, resource_type, public_file)
        is_valid, message = self.__is_input_valid(path, resource_type,
                                                  file_type, public_file)
        self._request_sender = request_sender
        if not is_valid:
            logging.info(message)

    def get_file_info(self):
        return self._file_request

    def upload(self):
        file_uploader_factory = FileUploaderFactory(self._file_request,
                                                    self._request_sender)
        file_uploader = file_uploader_factory.get_file_uploader(
            self._file_request.resource_type)
        try:
            result = file_uploader.upload()
        except EduKitException as e:
            raise EduKitException(str(e))
        logging.info("Uploaded successfully!")
        return result

    def __is_input_valid(self, path, resource_type, file_type, public_file):
        """
        判断传入的参数是否符合要求
        :param path: 需要上传的文件路径
        :param resource_type: 资源文件类型
        :param file_type: 媒体文件类型
        :param public_file:
        :return:
        """
        is_valid = False
        message = ''

        if not path:
            message = ErrorConstant.PATH_NOT_NULL
            logging.info(message)
        if re.match(self._relative_path_pattern, path):
            message = ErrorConstant.PATH_NOT_ABSOLUTE
            return is_valid, message
        if not os.path.exists(path):
            message = ErrorConstant.FILE_NOT_EXISTS.format(
                self.get_logfile_path(resource_type, path))
            return is_valid, message
        if os.path.isdir(path):
            message = ErrorConstant.PATH_IS_DIRECTORY.format(path)
            return is_valid, message
        if resource_type:
            if file_type or public_file:
                message = ErrorConstant.FILE_TYPE_OR_PUBLIC_FILE_NOT_NULL
                return is_valid, message
            if resource_type not in self._resource_type_dict.values():
                message = ErrorConstant.RESOURCE_TYPE_IS_INVALID
                return is_valid, message
        else:
            if not file_type:
                message = ErrorConstant.FILE_TYPE_NO_VALUE
                return is_valid, message

        is_valid = True
        return is_valid, message

    @staticmethod
    def get_logfile_path(resource_type, path):
        return '' if resource_type == FileUploadConstant.RESOURCE_TYPE.get(
            ClientConstant.TUTOR_PORTRAIT) else path

    def __get_init_object(self, path, file_type, resource_type, public_file):
        self._file_request = FileUploadRequest(path, file_type, resource_type,
                                               public_file)



# -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class CatalogueConstant:
    CREATE_CATALOGUE_RESPONSE = 'edukit_sdk.edukit.catalogue' \
                                '.resp.create_catalogue_response' \
                                '.CreateCatalogueResponse'
    UPDATE_CATALOGUE_RESPONSE = 'edukit_sdk.edukit.catalogue.resp' \
                                '.update_catalogue_response' \
                                '.UpdateCatalogueResponse'
    RESULT = 'result'
    RESULT_CODE = 'resultCode'
    RESULT_DESC = 'resultDesc'



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class ImageFileInfo:
    def __init__(self):
        self._path = None
        self._resource_type = None

    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, path):
        self._path = path

    @property
    def resource_type(self):
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        self._resource_type = resource_type



#  -*- coding: utf-8 -*-
#  Copyright (c) Huawei Technologies Co., Ltd. 2021-2021. All rights reserved.


class PkgLocalizedData:
    def __init__(self):
        self._language = None
        self._name = None
        self._cover_image_info = None
        self._full_description = None
        self._introduce_infos = None
        self._cover_image_id = None
        self._introduce_ids = None

    @property
    def language(self):
        """
        :return:mixed
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        语言代码由[BCP-47]定义，如简体中文为"zh-CN"，区分大小写（语言标识使用小写字母；区域名称使用大写字母
        :param language:
        :return:
        """
        self._language = language

    @property
    def cover_image_info(self):
        """
        :return: mixed
        """
        return self._cover_image_info

    @cover_image_info.setter
    def cover_image_info(self, cover_image_info):
        """
        会员包封面图片
        :param cover_image_info:
        :return:
        """
        self._cover_image_info = cover_image_info

    @property
    def name(self):
        """
        :return:mixed
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        会员包名称
        :param name:
        :return:
        """
        self._name = name

    @property
    def introduce_infos(self):
        """
        :return:mixed
        """
        return self._introduce_infos

    @introduce_infos.setter
    def introduce_infos(self, introduce_infos):
        """
        介绍图片素材Id列表，更新时必须全量提交
        :param introduce_infos:
        :return:
        """
        self._introduce_infos = introduce_infos

    @property
    def cover_image_id(self):
        """
        :return:mixed
        """
        return self._cover_image_id

    @cover_image_id.setter
    def cover_image_id(self, cover_image_id):
        """
        会员包封面图片文件的素材ID
        :param cover_image_id:
        :return:
        """
        self._cover_image_id = cover_image_id

    @property
    def full_description(self):
        """
        :return:mixed
        """
        return self._full_description

    @full_description.setter
    def full_description(self, full_description):
        """
        会员包详细介绍。最大2000字符
        :param full_description:
        :return:
        """
        self._full_description = full_description

    @property
    def introduce_ids(self):
        """
        :return:mixed
        """
        return self._introduce_ids

    @introduce_ids.setter
    def introduce_ids(self, introduce_ids):
        """
        会员包介绍图片文件的素材ID列表
        :param introduce_ids:
        :return:
        """
        self._introduce_ids = introduce_ids
